@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/lib/error.c,v 1.39 2005/01/13 19:54:45 bboy Exp $
+	$Id: error.c,v 1.42 2005/04/20 16:49:11 bboy Exp $
+
 	error.c: Error reporting and message output functions.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -24,7 +25,7 @@
 #define ERROR_MAXMSGLEN	1024
 
 /* The name of the currently running program */
-char	*progname = PACKAGE;
+char	*progname = (char *)PACKAGE;
 
 /* Should ERR_VERBOSE cause output? */
 int	err_verbose = 0;
@@ -149,8 +150,7 @@ _error_out(
    This is called by the macro "Assert" if an assertion fails.
 **************************************************************************************************/
 void
-_error_assert_fail(assertion)
-	const char *assertion;
+_error_assert_fail(const char *assertion)
 {
 	char msg[BUFSIZ];
 
@@ -346,6 +346,39 @@ WarnSQL(
 /*--- WarnSQL() ---------------------------------------------------------------------------------*/
 
 
+/**************************************************************************************************
+	SQL_ERRMSG
+**************************************************************************************************/
+char *
+sql_errmsg(
+#if USE_PGSQL
+	PGconn *pgsql
+#else
+	MYSQL *mysql
+#endif
+)
+{
+	static char msg[BUFSIZ];
+
+#if USE_PGSQL
+	{
+		char *errmsg = PQerrorMessage(pgsql), *c;
+
+		for (c = errmsg; *c; c++)
+			if (*c == '\r' || *c == '\n')
+				*c = ' ';
+		strtrim(errmsg);
+
+		snprintf(msg, sizeof(msg), "%s (errno=%d)", errmsg, errno);
+	}
+#else
+	snprintf(msg, sizeof(msg), "%s (errno=%d)", mysql_error(mysql), errno);
+#endif
+	return (msg);
+}
+/*--- sql_errmsg() ------------------------------------------------------------------------------*/
+
+
 /**************************************************************************************************
 	ERRSQL
 **************************************************************************************************/
