@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/lib/mydnsutil.h,v 1.61 2005/01/13 19:54:45 bboy Exp $
+	$Id: mydnsutil.h,v 1.68 2005/04/28 18:43:46 bboy Exp $
+
 	mydnsutil.h: Support library for the MyDNS package.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -27,27 +28,33 @@
 /* <unistd.h> should be included before any preprocessor test
    of _POSIX_VERSION.  */
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#	include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 
+#ifdef HAVE_INTTYPES_H
+#	include <inttypes.h>
+#endif
+
 #include <stdio.h>
 #include <sys/types.h>
 
 #ifdef HAVE_LIMITS_H
-#include <limits.h>
+#	include <limits.h>
 #endif
-#ifdef HAVE_STDARG_H
-#include <stdarg.h>
-#endif
-#include <ctype.h>
 
+#ifdef HAVE_STDARG_H
+#	include <stdarg.h>
+#endif
+
+#include <ctype.h>
 #include <syslog.h>
 
 #ifdef HAVE_LOCALE_H
-#include <locale.h>
+#	include <locale.h>
 #endif
+
 #ifndef HAVE_SETLOCALE
-#define setlocale(category,locale) /* empty */
+#	define setlocale(category,locale) /* empty */
 #endif
 
 /* For gettext (NLS).  */
@@ -56,9 +63,9 @@
 #define N_(String) (String)
 
 #ifdef STDC_HEADERS
-#define getopt system_getopt
-#include <stdlib.h>
-#undef getopt
+#	define getopt system_getopt
+#	include <stdlib.h>
+#	undef getopt
 #else
 extern char *getenv ();
 #endif
@@ -110,7 +117,7 @@ extern int strcoll ();
 #endif
 
 #include <sys/stat.h>
-#if STAT_MACROS_BROKEN
+#ifdef STAT_MACROS_BROKEN
 # undef S_ISDIR
 #endif
 #if !defined(S_ISDIR) && defined(S_IFDIR)
@@ -253,23 +260,23 @@ extern int strcoll ();
 #	include <pwd.h>
 #endif
 
-#if !HAVE_UCHAR
+#ifndef HAVE_UCHAR
 typedef unsigned char uchar;
 #endif
 
-#if !HAVE_UINT
+#ifndef HAVE_UINT
 typedef unsigned int uint;
 #endif
 
-#if !HAVE_UINT8_T
+#ifndef HAVE_UINT8_T
 typedef unsigned char uint8_t;
 #endif
 
-#if !HAVE_UINT16_T
+#ifndef HAVE_UINT16_T
 typedef unsigned short uint16_t;
 #endif
 
-#if !HAVE_UINT32_T
+#ifndef HAVE_UINT32_T
 typedef unsigned int uint32_t;
 #endif
 
@@ -378,9 +385,11 @@ extern void Errx(const char *, ...) __printflike(1,2);
 #if USE_PGSQL
 extern int	WarnSQL(PGconn *, const char *, ...) __printflike(2,3);
 extern void ErrSQL(PGconn *, const char *, ...) __printflike(2,3);
+extern char *sql_errmsg(PGconn *);
 #else
 extern int	WarnSQL(MYSQL *, const char *, ...) __printflike(2,3);
 extern void ErrSQL(MYSQL *, const char *, ...) __printflike(2,3);
+extern char *sql_errmsg(MYSQL *);
 #endif
 
 #if !HAVE_DECL_STRSEP
@@ -421,12 +430,15 @@ extern int		sdprintf(char **, const char *, ...) __printflike(2,3);
 extern size_t	human_file_size(const char *);
 extern void		escdata(char *, int);
 extern char		*bytestr(unsigned char);
-extern char		*escstr();
+extern char		*escstr(char *, size_t);
 extern char		*comma(unsigned long);
 extern char		*comma1(unsigned long);
 extern char		*comma2(unsigned long);
 extern char		*comma3(unsigned long);
 
+/* strsep_quotes.c */
+extern char		*strsep_quotes(char **, char *, size_t);
+
 /* wildcard.c */
 extern int		wildcard_valid(char *p);
 extern int		wildcard_match(register char *, register char *);
