@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/lib/passinput.c,v 1.8 2005/01/13 19:54:46 bboy Exp $
+	$Id: passinput.c,v 1.10 2005/04/20 16:49:11 bboy Exp $
+
 	passinput.c: Read a password from standard input.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -19,10 +20,11 @@
 	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **************************************************************************************************/
 
-#include <signal.h>
-#include <stdio.h>
-#include <termios.h>
-#include <unistd.h>
+//#include <signal.h>
+//#include <stdio.h>
+//#include <termios.h>
+//#include <unistd.h>
+#include "mydnsutil.h"
 
 #ifndef PASS_MAX
 #	define PASS_MAX	128
