@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/lib/string.c,v 1.20 2005/01/13 19:54:46 bboy Exp $
+	$Id: string.c,v 1.22 2005/04/20 16:49:11 bboy Exp $
+
 	string.c: Typical generic string manipulation routines.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -322,24 +323,16 @@ escstr(char *str, size_t len)
 static size_t
 commafmt(char *buf, size_t bufsiz, unsigned long N)
 {
-	int len = 1, posn = 1, sign = 1;
+	unsigned int len = 1, posn = 1;
 	char *ptr = buf + bufsiz - 1;
 
-	if (2 > bufsiz)
+	if (bufsiz < 2)
 	{
-ABORT:*buf = '\0';
+		*buf = '\0';
 		return 0;
 	}
-
 	*ptr-- = '\0';
 	--bufsiz;
-
-	if (0L > N)
-	{
-		sign = -1;
-		N = -N;
-	}
-
 	for ( ; len <= bufsiz; ++len, ++posn)
 	{
 		*ptr-- = (char)((N % 10L) + '0');
@@ -351,17 +344,12 @@ ABORT:*buf = '\0';
 			++len;
 		}
 		if (len >= bufsiz)
-			goto ABORT;
-	}
-	if (0 > sign)
-	{
-		if (0 == bufsiz)
-			goto ABORT;
-		*ptr-- = '-';
-		++len;
+		{
+			*buf = '\0';
+			return 0;
+		}
 	}
 	strcpy(buf, ++ptr);
-
 	return (size_t)len;
 }
 /*--- commafmt() --------------------------------------------------------------------------------*/
