@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/lib/mydns.h,v 1.90 2005/01/13 19:54:46 bboy Exp $
+	$Id: mydns.h,v 1.97 2005/04/28 17:44:54 bboy Exp $
+
 	libmydns.h: Header file for the MyDNS library.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -52,6 +53,12 @@ extern int mydns_soa_use_xfer;
 #define mydns_set_soa_use_xfer(S)	\
 				(mydns_soa_use_xfer = sql_iscolumn((S), mydns_soa_table_name, "xfer"))
 
+/* This is set by mydns_set_soa_use_update */
+extern int mydns_soa_use_update;
+#define mydns_set_soa_use_update(S)	\
+				(mydns_soa_use_update = sql_iscolumn((S), mydns_soa_table_name, "update"))
+
+
 /* This is set by mydns_set_rr_use_stamp (currently unimplemented - for future IXFR support */
 extern int mydns_rr_use_stamp;
 #define mydns_set_rr_use_stamp(S)	\
@@ -122,16 +129,23 @@ typedef enum _task_error_t					/* Common errors */
 	ERR_TIMEOUT,								/* "Communications timeout" */
 	ERR_BROKEN_GLUE,							/* "Malformed glue" */
 	ERR_INVALID_ADDRESS,						/* "Invalid address" */
+	ERR_INVALID_TYPE,							/* "Invalid type" */
+	ERR_INVALID_CLASS,						/* "Invalid class" */
+	ERR_INVALID_TTL,							/* "Invalid TTL" (for update) */
+	ERR_INVALID_DATA,							/* "Invalid data" (for update) */
 	ERR_DB_ERROR,								/* "Database error" */
 	ERR_NO_QUESTION,							/* "No question in query" */
 	ERR_MULTI_QUESTIONS,						/* "Multiple questions in query" */
 	ERR_QUESTION_TRUNCATED,					/* "Question truncated" */
 	ERR_UNSUPPORTED_OPCODE,					/* "Unsupported opcode" */
+	ERR_UNSUPPORTED_TYPE,					/* "Unsupported type" */
 	ERR_MALFORMED_REQUEST,					/* "Malformed request" */
 	ERR_AXFR_NOT_ENABLED,					/* "AXFR not enabled" */
 	ERR_TCP_NOT_ENABLED,						/* "TCP not enabled" */
 	ERR_RESPONSE_BIT_SET,					/* "Response bit set on query" */
 	ERR_FWD_RECURSIVE,						/* "Recursive query forwarding error" */
+	ERR_NO_UPDATE,								/* "UPDATE denied" */
+	ERR_PREREQUISITE_FAILED,				/* "UPDATE prerequisite failed" */
 
 } task_error_t;
 
@@ -143,6 +157,8 @@ typedef enum									/* Query classes */
 	DNS_CLASS_IN		= 1,					/* Internet */
 	DNS_CLASS_CHAOS	= 3,					/* CHAOS (obsolete) */
 	DNS_CLASS_HESIOD	= 4,					/* HESIOD (obsolete) */
+
+	DNS_CLASS_NONE		= 254,				/* NONE (RFC 2136) */
 	DNS_CLASS_ANY		= 255					/* ANY */
 
 } dns_class_t;
@@ -232,6 +248,7 @@ typedef enum
 	DNS_RCODE_NXDOMAIN	= 3,				/* Nonexistent domain (RFC 1035) */
 	DNS_RCODE_NOTIMP		= 4,				/* Not implemented (RFC 1035) */
 	DNS_RCODE_REFUSED		= 5,				/* Query refused (RFC 1035) */
+
 	DNS_RCODE_YXDOMAIN	= 6,				/* Name exists when it should not (RFC 2136) */
 	DNS_RCODE_YXRRSET		= 7,				/* RR set exists when it should not (RFC 2136) */
 	DNS_RCODE_NXRRSET		= 8,				/* RR set that should exist does not (RFC 2136) */
@@ -275,9 +292,9 @@ typedef enum _datasection_t				/* Sections in reply */
 typedef struct _mydns_soa							/* `soa' table data (zones of authority) */
 {
 	uint32_t		id;
-	char			origin[DNS_MAXNAMELEN+1];
-	char			ns[DNS_MAXNAMELEN+1];
-	char			mbox[DNS_MAXNAMELEN+1];
+	char			origin[DNS_MAXNAMELEN + 1];
+	char			ns[DNS_MAXNAMELEN + 1];
+	char			mbox[DNS_MAXNAMELEN + 1];
 	uint32_t		serial;
 	uint32_t		refresh;
 	uint32_t		retry;
@@ -308,6 +325,19 @@ typedef struct _mydns_rr							/* `rr' table data (resource records) */
 	/* For RP records, this points to the "txt" part of the data, which is preceded by a NUL */
 	char			rp_txt[DNS_MAXNAMELEN + 1];
 
+	/* Data for NAPTR records: */
+	/* This is potentially a lot of data.  I'm a little unclear from the RFC on what the
+		maximum length of some of these fields are, so I'm just making them big for now.
+		Hopefully these extra fields won't take up too much extra memory in the cache, slowing
+		down the mere mortals who don't use NAPTR -- these fields add over 700 bytes to this
+		structure */
+	uint16_t		naptr_order;
+	uint16_t		naptr_pref;
+	char			naptr_flags[8];
+	char			naptr_service[DNS_MAXNAMELEN + 1];
+	char			naptr_regex[DNS_MAXNAMELEN + 1];
+	char			naptr_replacement[DNS_MAXNAMELEN + 1];
+
 	struct _mydns_rr *next;
 } MYDNS_RR;
 
@@ -344,7 +374,8 @@ extern char			*dns_make_question(uint16_t id, dns_qtype_t qtype, char *name, int
 extern long			mydns_rr_count(SQL *);
 extern void			mydns_set_rr_table_name(char *);
 extern void			mydns_set_rr_where_clause(char *);
-extern MYDNS_RR	*mydns_parse_rr(SQL_ROW, const char *);
+extern dns_qtype_t mydns_rr_get_type(char *);
+extern MYDNS_RR	*mydns_rr_parse(SQL_ROW, const char *);
 extern int			mydns_rr_load(SQL *, MYDNS_RR **, uint32_t, dns_qtype_t, char *, char *);
 extern MYDNS_RR	*mydns_rr_dup(MYDNS_RR *, int);
 extern size_t		mydns_rr_size(MYDNS_RR *);
@@ -356,7 +387,7 @@ extern void			_mydns_rr_free(MYDNS_RR *);
 extern long			mydns_soa_count(SQL *);
 extern void			mydns_set_soa_table_name(char *);
 extern void			mydns_set_soa_where_clause(char *);
-extern MYDNS_SOA	*mydns_parse_soa(SQL_ROW);
+extern MYDNS_SOA	*mydns_soa_parse(SQL_ROW);
 extern int			mydns_soa_load(SQL *, MYDNS_SOA **, char *);
 extern int			mydns_soa_make(SQL *, MYDNS_SOA **, unsigned char *, unsigned char *);
 extern MYDNS_SOA	*mydns_soa_dup(MYDNS_SOA *, int);
