@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/lib/rr.c,v 1.55 2005/01/13 19:54:46 bboy Exp $
+	$Id: rr.c,v 1.65 2005/04/29 16:10:27 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -36,10 +36,9 @@ int mydns_rr_use_stamp = 0;
 	Returns the number of records in the rr table.
 **************************************************************************************************/
 long
-mydns_rr_count(sql)
-	SQL *sql;
+mydns_rr_count(SQL *sqlConn)
 {
-	return sql_count(sql, "SELECT COUNT(*) FROM %s", mydns_rr_table_name);
+	return sql_count(sqlConn, "SELECT COUNT(*) FROM %s", mydns_rr_table_name);
 }
 /*--- mydns_rr_count() --------------------------------------------------------------------------*/
 
@@ -48,8 +47,7 @@ mydns_rr_count(sql)
 	MYDNS_SET_RR_TABLE_NAME
 **************************************************************************************************/
 void
-mydns_set_rr_table_name(name)
-	char *name;
+mydns_set_rr_table_name(char *name)
 {
 	if (!name)
 		strncpy(mydns_rr_table_name, MYDNS_RR_TABLE, sizeof(mydns_rr_table_name)-1);
@@ -77,10 +75,7 @@ mydns_set_rr_where_clause(char *where)
 /**************************************************************************************************
 	MYDNS_RR_GET_TYPE
 **************************************************************************************************/
-#if !PROFILING
-inline
-#endif
-dns_qtype_t
+inline dns_qtype_t
 mydns_rr_get_type(char *type)
 {
 	register char *c;
@@ -121,6 +116,8 @@ mydns_rr_get_type(char *type)
 		case 'N':
 			if (type[1] == 'S' && !type[2])
 				return DNS_QTYPE_NS;
+			if (type[1] == 'A' && type[2] == 'P' && type[3] == 'T' && type[4] == 'R' && !type[5])
+				return DNS_QTYPE_NAPTR;
 			break;
 
 		case 'T':
@@ -149,75 +146,159 @@ mydns_rr_get_type(char *type)
 
 
 /**************************************************************************************************
-	MYDNS_PARSE_RR
+	MYDNS_RR_PARSE_RP
+	RP contains two names in 'data' -- the mbox and the txt.
+	NUL-terminate mbox and fill 'rp_txt' with the txt part of the record.
 **************************************************************************************************/
-#if !PROFILING
-inline
-#endif
-MYDNS_RR *
-mydns_parse_rr(SQL_ROW row, const char *origin)
+static inline void
+mydns_rr_parse_rp(SQL_ROW row, const char *origin, MYDNS_RR *rr)
 {
-	MYDNS_RR *rv;
+	char *c;
 
-	if ((rv = (MYDNS_RR *)calloc(1, sizeof(MYDNS_RR))))
+	/* If no space, set txt to '.' */
+	if (!(c = strchr(rr->data, ' ')))
 	{
-		rv->next = NULL;
+		rr->rp_txt[0] = '.';
+		rr->rp_txt[1] = '\0';
+	}
+	else
+	{
+		strncpy(rr->rp_txt, c+1, sizeof(rr->rp_txt)-1);
+		*c = '\0';
 
-		rv->id = atou(row[0]);
-		rv->zone = atou(row[1]);
-		strncpy(rv->name, row[2], sizeof(rv->name)-1);
-		strncpy(rv->data, row[3], sizeof(rv->data)-1);
-		rv->class = DNS_CLASS_IN;
-		rv->aux = atou(row[4]);
-		rv->ttl = atou(row[5]);
-		if (!(rv->type = mydns_rr_get_type(row[6])))
+		/* Append origin to rp_txt if necessary */
+		{
+			int namelen = strlen(rr->rp_txt);
+			if (namelen && rr->rp_txt[namelen-1] != '.')
+			{
+				strncat(rr->rp_txt, ".", sizeof(rr->rp_txt) - namelen - 1);
+				strncat(rr->rp_txt, origin, sizeof(rr->rp_txt) - namelen - 2);
+			}
+		}
+	}
+}
+/*--- mydns_rr_parse_rp() -----------------------------------------------------------------------*/
+
+
+/**************************************************************************************************
+	MYDNS_RR_PARSE_SRV
+	SRV records contain two unsigned 16-bit integers in the "data" field before the target,
+	'srv_weight' and 'srv_port' - parse them and make "data" contain only the target.  Also, make
+	sure 'aux' fits into 16 bits, clamping values above 65535.
+**************************************************************************************************/
+static inline void
+mydns_rr_parse_srv(SQL_ROW row, const char *origin, MYDNS_RR *rr)
+{
+	char *weight, *port, *target;
+
+	/* Clamp 'aux' if necessary */
+	if (rr->aux > 65535)
+		rr->aux = 65535;
+
+	/* Parse weight (into srv_weight), port (into srv_port), and target */
+	target = rr->data;
+	if ((weight = strsep(&target, " \t")))
+	{
+		rr->srv_weight = atoi(weight);
+		if ((port = strsep(&target, " \t")))
+			rr->srv_port = atoi(port);
+		memmove(rr->data, target, strlen(target)+1);
+	}
+}
+/*--- mydns_rr_parse_srv() ----------------------------------------------------------------------*/
+
+
+/**************************************************************************************************
+	MYDNS_RR_PARSE_NAPTR
+	Returns 0 on success, -1 on error.
+**************************************************************************************************/
+static inline int
+mydns_rr_parse_naptr(SQL_ROW row, const char *origin, MYDNS_RR *rr)
+{
+	char int_tmp[12], data_copy[DNS_MAXNAMELEN * 2 + 2], *p;
+
+	strncpy(data_copy, rr->data, sizeof(data_copy) - 1);
+	p = data_copy;
+
+	if (!strsep_quotes(&p, int_tmp, sizeof(int_tmp)))
+		return (-1);
+	rr->naptr_order = atoi(int_tmp);
+
+	if (!strsep_quotes(&p, int_tmp, sizeof(int_tmp)))
+		return (-1);
+	rr->naptr_pref = atoi(int_tmp);
+
+	if (!strsep_quotes(&p, rr->naptr_flags, sizeof(rr->naptr_flags)))
+		return (-1);
+
+	if (!strsep_quotes(&p, rr->naptr_service, sizeof(rr->naptr_service)))
+		return (-1);
+
+	if (!strsep_quotes(&p, rr->naptr_regex, sizeof(rr->naptr_regex)))
+		return (-1);
+
+	if (!strsep_quotes(&p, rr->naptr_replacement, sizeof(rr->naptr_replacement)))
+		return (-1);
+
+	return 0;
+}
+/*--- mydns_rr_parse_naptr() --------------------------------------------------------------------*/
+
+
+/**************************************************************************************************
+	MYDNS_RR_PARSE
+	Given the SQL results with RR data, populates and returns a matching MYDNS_RR structure.
+	Returns NULL on error.
+**************************************************************************************************/
+inline MYDNS_RR *
+mydns_rr_parse(SQL_ROW row, const char *origin)
+{
+	MYDNS_RR *rr;
+
+	if ((rr = (MYDNS_RR *)calloc(1, sizeof(MYDNS_RR))))
+	{
+		rr->next = NULL;
+
+		rr->id = atou(row[0]);
+		rr->zone = atou(row[1]);
+		strncpy(rr->name, row[2], sizeof(rr->name)-1);
+		strncpy(rr->data, row[3], sizeof(rr->data)-1);
+		rr->class = DNS_CLASS_IN;
+		rr->aux = atou(row[4]);
+		rr->ttl = atou(row[5]);
+		if (!(rr->type = mydns_rr_get_type(row[6])))
 		{
 			/* Ignore unknown RR type(s) */
-			free(rv);
+			free(rr);
 			return (NULL);
 		}
 #if ALIAS_ENABLED
-		if (rv->type == DNS_QTYPE_ALIAS)
+		if (rr->type == DNS_QTYPE_ALIAS)
 		{
-			rv->type = DNS_QTYPE_A;
-			rv->alias = 1;
+			rr->type = DNS_QTYPE_A;
+			rr->alias = 1;
 		}
 		else
-			rv->alias = 0;
+			rr->alias = 0;
 #endif
 
-		/* RP contains two names in 'data' -- the mbox and the txt.
-			NUL-terminate mbox and fill 'rp_txt' with the txt part of the record. */
-		if (rv->type == DNS_QTYPE_RP)
+		/* Populate special fields for RP records */
+		if (rr->type == DNS_QTYPE_RP)
+			mydns_rr_parse_rp(row, origin, rr);
+
+		/* Populate special fields for NAPTR records */
+		if (rr->type == DNS_QTYPE_NAPTR)
 		{
-			char *c;
-
-			/* If no space, set txt to '.' */
-			if (!(c = strchr(rv->data, ' ')))
+			if (mydns_rr_parse_naptr(row, origin, rr) < 0)
 			{
-				rv->rp_txt[0] = '.';
-				rv->rp_txt[1] = '\0';
-			}
-			else
-			{
-				strncpy(rv->rp_txt, c+1, sizeof(rv->rp_txt)-1);
-				*c = '\0';
-
-				/* Append origin to rp_txt if necessary */
-				{
-					int namelen = strlen(rv->rp_txt);
-					if (namelen && rv->rp_txt[namelen-1] != '.')
-					{
-						strncat(rv->rp_txt, ".", sizeof(rv->rp_txt) - namelen - 1);
-						strncat(rv->rp_txt, origin, sizeof(rv->rp_txt) - namelen - 2);
-					}
-				}
+				free(rr);
+				return (NULL);
 			}
 		}
 
 		/* Append origin to data if it's not there for these types: */
 		if (origin)
-			switch (rv->type)
+			switch (rr->type)
 			{
 				case DNS_QTYPE_CNAME:
 				case DNS_QTYPE_MX:
@@ -226,14 +307,14 @@ mydns_parse_rr(SQL_ROW row, const char *origin)
 				case DNS_QTYPE_SRV:
 #ifdef DN_COLUMN_NAMES
 					/* Just append dot for DN */
-					strncat(rv->data, ".", sizeof(rv->data) - strlen(rv->data) - 1);
+					strncat(rr->data, ".", sizeof(rr->data) - strlen(rr->data) - 1);
 #else
 					{
-						int namelen = strlen(rv->data);
-						if (namelen && rv->data[namelen-1] != '.')
+						int namelen = strlen(rr->data);
+						if (namelen && rr->data[namelen-1] != '.')
 						{
-							strncat(rv->data, ".", sizeof(rv->data) - namelen - 1);
-							strncat(rv->data, origin, sizeof(rv->data) - namelen - 2);
+							strncat(rr->data, ".", sizeof(rr->data) - namelen - 1);
+							strncat(rr->data, origin, sizeof(rr->data) - namelen - 2);
 						}
 					}
 #endif
@@ -241,41 +322,21 @@ mydns_parse_rr(SQL_ROW row, const char *origin)
 				default: break;
 			}
 
-		/* SRV records contain two unsigned 16-bit integers in the "data" field before
-			the target, 'srv_weight' and 'srv_port' - parse them and make "data" contain
-			only the target.  Also, make sure 'aux' fits into 16 bits,
-			clamping values above 65535. */
-		if (rv->type == DNS_QTYPE_SRV)
-		{
-			char *weight, *port, *target;
-
-			/* Clamp 'aux' if necessary */
-			if (rv->aux > 65535)
-				rv->aux = 65535;
-
-			/* Parse weight (into srv_weight), port (into srv_port), and target */
-			target = rv->data;
-			if ((weight = strsep(&target, " \t")))
-			{
-				rv->srv_weight = atoi(weight);
-				if ((port = strsep(&target, " \t")))
-					rv->srv_port = atoi(port);
-				memmove(rv->data, target, strlen(target)+1);
-			}
-		}
+		if (rr->type == DNS_QTYPE_SRV)
+			mydns_rr_parse_srv(row, origin, rr);
 	}
-	return (rv);
+	return (rr);
 }
-/*--- mydns_parse_rr() --------------------------------------------------------------------------*/
+/*--- mydns_rr_parse() --------------------------------------------------------------------------*/
 
 
 /**************************************************************************************************
 	MYDNS_RR_DUP
+	Make and return a copy of a MYDNS_RR record.  If 'recurse' is specified, copies all records
+	in the RRset.
 **************************************************************************************************/
 MYDNS_RR *
-mydns_rr_dup(start, recurse)
-	MYDNS_RR *start;
-	int recurse;
+mydns_rr_dup(MYDNS_RR *start, int recurse)
 {
 	register MYDNS_RR *first = NULL, *last = NULL, *rr, *s, *tmp;
 
@@ -283,39 +344,48 @@ mydns_rr_dup(start, recurse)
 	{
 		tmp = s->next;
 
-		if ((rr = (MYDNS_RR *)calloc(1, sizeof(MYDNS_RR))))
-		{
-			rr->id = s->id;
-			rr->zone = s->zone;
-			strncpy(rr->name, s->name, sizeof(rr->name)-1);
-			rr->type = s->type;
-			rr->class = s->class;
-			strncpy(rr->data, s->data, sizeof(rr->data)-1);
-			rr->aux = s->aux;
-			rr->ttl = s->ttl;
+		if (!(rr = (MYDNS_RR *)calloc(1, sizeof(MYDNS_RR))))
+			Err(_("out of memory"));
+
+		rr->id = s->id;
+		rr->zone = s->zone;
+		strncpy(rr->name, s->name, sizeof(rr->name)-1);
+		rr->type = s->type;
+		rr->class = s->class;
+		strncpy(rr->data, s->data, sizeof(rr->data)-1);
+		rr->aux = s->aux;
+		rr->ttl = s->ttl;
 #if ALIAS_ENABLED
-			rr->alias = s->alias;
+		rr->alias = s->alias;
 #endif
 
-			rr->srv_weight = s->srv_weight;
-			rr->srv_port = s->srv_port;
+		rr->srv_weight = s->srv_weight;
+		rr->srv_port = s->srv_port;
 
-			/* Copy rp_txt only for RP records */
-			if (rr->type == DNS_QTYPE_RP)
-				strncpy(rr->rp_txt, s->rp_txt, sizeof(rr->rp_txt)-1);
-			else
-				rr->rp_txt[0] = '\0';
+		/* Copy rp_txt only for RP records */
+		if (rr->type == DNS_QTYPE_RP)
+			strncpy(rr->rp_txt, s->rp_txt, sizeof(rr->rp_txt) - 1);
 
-			rr->next = NULL;
-			if (recurse)
-			{
-				if (!first) first = rr;
-				if (last) last->next = rr;
-				last = rr;
-			}
-			else
-				return (rr);
+		/* Copy naptr fields only for NAPTR records */
+		if (rr->type == DNS_QTYPE_NAPTR)
+		{
+			rr->naptr_order = s->naptr_order;
+			rr->naptr_pref = s->naptr_pref;
+			strncpy(rr->naptr_flags, s->naptr_flags, sizeof(rr->naptr_flags) - 1);
+			strncpy(rr->naptr_service, s->naptr_service, sizeof(rr->naptr_service) - 1);
+			strncpy(rr->naptr_regex, s->naptr_regex, sizeof(rr->naptr_regex) - 1);
+			strncpy(rr->naptr_replacement, s->naptr_replacement, sizeof(rr->naptr_replacement) - 1);
 		}
+
+		rr->next = NULL;
+		if (recurse)
+		{
+			if (!first) first = rr;
+			if (last) last->next = rr;
+			last = rr;
+		}
+		else
+			return (rr);
 	}
 	return (first);
 }
@@ -325,12 +395,8 @@ mydns_rr_dup(start, recurse)
 /**************************************************************************************************
 	MYDNS_RR_SIZE
 **************************************************************************************************/
-#if !PROFILING
-inline
-#endif
-size_t
-mydns_rr_size(first)
-	MYDNS_RR *first;
+inline size_t
+mydns_rr_size(MYDNS_RR *first)
 {
 	register MYDNS_RR *p;
 	register size_t size = 0;
@@ -347,10 +413,7 @@ mydns_rr_size(first)
 	_MYDNS_RR_FREE
 	Frees the pointed-to structure.	Don't call this function directly, call the macro.
 **************************************************************************************************/
-#if !PROFILING
-inline
-#endif
-void
+inline void
 _mydns_rr_free(MYDNS_RR *first)
 {
 	register MYDNS_RR *p, *tmp;
@@ -370,7 +433,8 @@ _mydns_rr_free(MYDNS_RR *first)
 	If "name" is NULL, all resource records for the zone will be loaded.
 **************************************************************************************************/
 int
-mydns_rr_load(SQL *sql, MYDNS_RR **rptr, uint32_t zone, dns_qtype_t type, char *name, char *origin)
+mydns_rr_load(SQL *sqlConn, MYDNS_RR **rptr, uint32_t zone,
+				  dns_qtype_t type, char *name, char *origin)
 {
 	MYDNS_RR *first = NULL, *last = NULL;
 	size_t	querylen;
@@ -386,13 +450,14 @@ mydns_rr_load(SQL *sql, MYDNS_RR **rptr, uint32_t zone, dns_qtype_t type, char *
 #endif
 
 #if DEBUG_ENABLED && DEBUG_LIB_RR
-	Debug("mydns_rr_load(zone=%u, type='%s', name='%s', origin='%s')", zone, mydns_qtype_str(type), name, origin);
+	Debug("mydns_rr_load(zone=%u, type='%s', name='%s', origin='%s')",
+			zone, mydns_qtype_str(type), name ?: "NULL", origin ?: "NULL");
 #endif
 
 	if (rptr) *rptr = NULL;
 
 	/* Verify args */
-	if (!sql || !rptr)
+	if (!sqlConn || !rptr)
 	{
 		errno = EINVAL;
 		return (-1);
@@ -410,6 +475,7 @@ mydns_rr_load(SQL *sql, MYDNS_RR **rptr, uint32_t zone, dns_qtype_t type, char *
 		case DNS_QTYPE_CNAME:	wheretype = " AND type='CNAME'"; break;
 		case DNS_QTYPE_HINFO:	wheretype = " AND type='HINFO'"; break;
 		case DNS_QTYPE_MX:		wheretype = " AND type='MX'"; break;
+		case DNS_QTYPE_NAPTR:	wheretype = " AND type='NAPTR'"; break;
 		case DNS_QTYPE_NS:		wheretype = " AND type='NS'"; break;
 		case DNS_QTYPE_PTR:		wheretype = " AND type='PTR'"; break;
 		case DNS_QTYPE_SOA:		wheretype = " AND type='SOA'"; break;
@@ -428,9 +494,12 @@ mydns_rr_load(SQL *sql, MYDNS_RR **rptr, uint32_t zone, dns_qtype_t type, char *
 			if (SQL_BADCHAR(*c))
 				return (0);
 	}
-	for (c = origin; *c; c++)
-		if (SQL_BADCHAR(*c))
-			return (0);
+	if (origin)
+	{
+		for (c = origin; *c; c++)
+			if (SQL_BADCHAR(*c))
+				return (0);
+	}
 
 #ifdef DN_COLUMN_NAMES
 	/* Remove dot from origin and name for DN */
@@ -496,7 +565,7 @@ mydns_rr_load(SQL *sql, MYDNS_RR **rptr, uint32_t zone, dns_qtype_t type, char *
 			(mydns_rr_where_clause) ? mydns_rr_where_clause : "");
 
 	/* Submit query */
-	if (!(res = sql_query(sql, query, querylen)))
+	if (!(res = sql_query(sqlConn, query, querylen)))
 		return (-1);
 
 #if DEBUG_ENABLED && DEBUG_LIB_RR
@@ -516,12 +585,13 @@ mydns_rr_load(SQL *sql, MYDNS_RR **rptr, uint32_t zone, dns_qtype_t type, char *
 		if (mydns_rr_use_active && row[MYDNS_RR_NUMFIELDS] && !GETBOOL(row[MYDNS_RR_NUMFIELDS]))
 			continue;
 
-		if (!(new = mydns_parse_rr(row, origin)))
+		if (!(new = mydns_rr_parse(row, origin)))
 			continue;
 
 		/* Always trim origin from name (XXX: Why? When did I add this?) */
 		/* Apparently removing this code breaks RRs where the name IS the origin */
-		if (origin && (cp = strstr(new->name, origin)))
+		/* But trim only where the name is exactly the origin */
+		if (origin && (cp = strstr(new->name, origin)) && !(cp - new->name))
 			*cp = '\0';
 
 		if (!first) first = new;
