@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/lib/soa.c,v 1.58 2005/01/13 19:54:46 bboy Exp $
+	$Id: soa.c,v 1.65 2005/12/18 19:16:41 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -26,6 +26,7 @@ char *mydns_soa_where_clause = NULL;
 /* Optional columns */
 int mydns_soa_use_active = 0;
 int mydns_soa_use_xfer = 0;
+int mydns_soa_use_update_acl = 0;
 
 /* Make this nonzero to enable debugging within this source file */
 #define	DEBUG_LIB_SOA	0
@@ -36,9 +37,9 @@ int mydns_soa_use_xfer = 0;
 	Returns the number of zones in the soa table.
 **************************************************************************************************/
 long
-mydns_soa_count(SQL *sql)
+mydns_soa_count(SQL *sqlConn)
 {
-	return sql_count(sql, "SELECT COUNT(*) FROM %s", mydns_soa_table_name);
+	return sql_count(sqlConn, "SELECT COUNT(*) FROM %s", mydns_soa_table_name);
 }
 /*--- mydns_soa_count() -------------------------------------------------------------------------*/
 
@@ -73,13 +74,13 @@ mydns_set_soa_where_clause(char *where)
 
 
 /**************************************************************************************************
-	MYDNS_PARSE_SOA
+	MYDNS_SOA_PARSE
 **************************************************************************************************/
 #if !PROFILING
 inline
 #endif
 MYDNS_SOA *
-mydns_parse_soa(SQL_ROW row)
+mydns_soa_parse(SQL_ROW row)
 {
 	MYDNS_SOA *rv;
 	int len;
@@ -123,12 +124,14 @@ mydns_parse_soa(SQL_ROW row)
 	}
 	return (rv);
 }
-/*--- mydns_parse_soa() -------------------------------------------------------------------------*/
+/*--- mydns_soa_parse() -------------------------------------------------------------------------*/
 
 
 /**************************************************************************************************
 	MYDNS_SOA_DUP
 	Create a duplicate copy of the record.
+	Make and return a copy of a MYDNS_SOA record.  If 'recurse' is specified, copies all records
+	in the list.
 **************************************************************************************************/
 MYDNS_SOA *
 mydns_soa_dup(MYDNS_SOA *start, int recurse)
@@ -139,28 +142,28 @@ mydns_soa_dup(MYDNS_SOA *start, int recurse)
 	{
 		tmp = s->next;
 
-		if ((soa = (MYDNS_SOA *)malloc(sizeof(MYDNS_SOA))))
+		if (!(soa = (MYDNS_SOA *)calloc(1, sizeof(MYDNS_SOA))))
+			Err(_("out of memory"));
+
+		soa->id = s->id;
+		strncpy(soa->origin, s->origin, sizeof(soa->origin)-1);
+		strncpy(soa->ns, s->ns, sizeof(soa->ns)-1);
+		strncpy(soa->mbox, s->mbox, sizeof(soa->mbox)-1);
+		soa->serial = s->serial;
+		soa->refresh = s->refresh;
+		soa->retry = s->retry;
+		soa->expire = s->expire;
+		soa->minimum = s->minimum;
+		soa->ttl = s->ttl;
+		soa->next = NULL;
+		if (recurse)
 		{
-			soa->id = s->id;
-			strncpy(soa->origin, s->origin, sizeof(soa->origin)-1);
-			strncpy(soa->ns, s->ns, sizeof(soa->ns)-1);
-			strncpy(soa->mbox, s->mbox, sizeof(soa->mbox)-1);
-			soa->serial = s->serial;
-			soa->refresh = s->refresh;
-			soa->retry = s->retry;
-			soa->expire = s->expire;
-			soa->minimum = s->minimum;
-			soa->ttl = s->ttl;
-			soa->next = NULL;
-			if (recurse)
-			{
-				if (!first) first = soa;
-				if (last) last->next = soa;
-				last = soa;
-			}
-			else
-				return (soa);
+			if (!first) first = soa;
+			if (last) last->next = soa;
+			last = soa;
 		}
+		else
+			return (soa);
 	}
 	return (first);
 }
@@ -213,7 +216,7 @@ _mydns_soa_free(MYDNS_SOA *first)
 	Returns 0 on success or nonzero if an error occurred.
 **************************************************************************************************/
 int
-mydns_soa_load(SQL *sql, MYDNS_SOA **rptr, char *origin)
+mydns_soa_load(SQL *sqlConn, MYDNS_SOA **rptr, char *origin)
 {
 	MYDNS_SOA		*first = NULL, *last = NULL;
 	size_t			querylen;
@@ -228,7 +231,7 @@ mydns_soa_load(SQL *sql, MYDNS_SOA **rptr, char *origin)
 	if (rptr) *rptr = NULL;
 
 	/* Verify args */
-	if (!sql || !origin || !rptr)
+	if (!sqlConn || !origin || !rptr)
 	{
 		errno = EINVAL;
 		return (-1);
@@ -264,7 +267,7 @@ mydns_soa_load(SQL *sql, MYDNS_SOA **rptr, char *origin)
 #endif
 
 	/* Submit query */
-	if (!(res = sql_query(sql, query, querylen)))
+	if (!(res = sql_query(sqlConn, query, querylen)))
 		return (-1);
 
 #if DEBUG_ENABLED && DEBUG_LIB_SOA
@@ -283,7 +286,7 @@ mydns_soa_load(SQL *sql, MYDNS_SOA **rptr, char *origin)
 		if (mydns_soa_use_active && row[MYDNS_SOA_NUMFIELDS] && !GETBOOL(row[MYDNS_SOA_NUMFIELDS]))
 			continue;
 
-		if (!(new = mydns_parse_soa(row)))
+		if (!(new = mydns_soa_parse(row)))
 		{
 			sql_free(res);
 			return (-1);
