@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Id: sql.c,v 1.21 2005/01/13 19:54:46 bboy Exp $
+	$Id: sql.c,v 1.22 2005/04/20 16:40:25 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -153,7 +153,7 @@ sql_reopen(void)
 	Returns 1 if the specified table exists in the current database, or 0 if it does not.
 **************************************************************************************************/
 int
-sql_istable(SQL *sql, const char *tablename)
+sql_istable(SQL *sqlConn, const char *tablename)
 {
 	unsigned char *xtablename;
 #if !USE_PGSQL
@@ -163,14 +163,14 @@ sql_istable(SQL *sql, const char *tablename)
 
 	if (!(xtablename = calloc(strlen(tablename) * 2 + 1, sizeof(unsigned char))))
 		Err(_("out of memory"));
-	sql_escstr(sql, xtablename, (uchar *)tablename, strlen(tablename));
+	sql_escstr(sqlConn, xtablename, (uchar *)tablename, strlen(tablename));
 
 #if USE_PGSQL
-	if (sql_count(sql, "SELECT COUNT(*) FROM pg_class"
+	if (sql_count(sqlConn, "SELECT COUNT(*) FROM pg_class"
 		 " WHERE (relkind='r' OR relkind='v') AND relname='%s'", xtablename) > 0)
 		rv = 1;
 #else
-	if ((res = sql_queryf(sql, "SHOW TABLES LIKE '%s'", xtablename)))
+	if ((res = sql_queryf(sqlConn, "SHOW TABLES LIKE '%s'", xtablename)))
 	{
 		if (sql_num_rows(res) > 0)
 			rv = 1;
@@ -189,7 +189,7 @@ sql_istable(SQL *sql, const char *tablename)
 	Returns 1 if the specified column exists in the current database, or 0 if it does not.
 **************************************************************************************************/
 int
-sql_iscolumn(SQL *sql, const char *tablename, const char *columnname)
+sql_iscolumn(SQL *sqlConn, const char *tablename, const char *columnname)
 {
 	unsigned char *xtablename, *xcolumnname;
 #if !USE_PGSQL
@@ -201,11 +201,11 @@ sql_iscolumn(SQL *sql, const char *tablename, const char *columnname)
 		Err(_("out of memory"));
 	if (!(xcolumnname = calloc(strlen(columnname) * 2 + 1, sizeof(unsigned char))))
 		Err(_("out of memory"));
-	sql_escstr(sql, xtablename, (uchar *)tablename, strlen(tablename));
-	sql_escstr(sql, xcolumnname, (uchar *)columnname, strlen(columnname));
+	sql_escstr(sqlConn, xtablename, (uchar *)tablename, strlen(tablename));
+	sql_escstr(sqlConn, xcolumnname, (uchar *)columnname, strlen(columnname));
 
 #if USE_PGSQL
-	if (sql_count(sql,
+	if (sql_count(sqlConn,
 			"SELECT COUNT(*)"
 			" FROM pg_class,pg_attribute"
 			" WHERE (relkind='r' OR relkind='v')"
@@ -214,7 +214,7 @@ sql_iscolumn(SQL *sql, const char *tablename, const char *columnname)
 			" AND attname='%s'", xtablename, xcolumnname) > 0)
 		rv = 1;
 #else
-	if ((res = sql_queryf(sql, "SHOW COLUMNS FROM %s LIKE '%s'", xtablename, xcolumnname)))
+	if ((res = sql_queryf(sqlConn, "SHOW COLUMNS FROM %s LIKE '%s'", xtablename, xcolumnname)))
 	{
 		if (sql_num_rows(res) > 0)
 			rv = 1;
@@ -233,12 +233,12 @@ sql_iscolumn(SQL *sql, const char *tablename, const char *columnname)
 	_SQL_CLOSE
 **************************************************************************************************/
 void
-_sql_close(SQL *sql)
+_sql_close(SQL *sqlConn)
 {
 #if USE_PGSQL
-	PQfinish(sql);
+	PQfinish(sqlConn);
 #else
-	mysql_close(sql);
+	mysql_close(sqlConn);
 #endif
 }
 /*--- _sql_close() ------------------------------------------------------------------------------*/
@@ -249,14 +249,14 @@ _sql_close(SQL *sql)
 	Issues an SQL query that does not return a result.  Returns 0 on success, -1 on error.
 **************************************************************************************************/
 int
-sql_nrquery(SQL *sql, const char *query, size_t querylen)
+sql_nrquery(SQL *sqlConn, const char *query, size_t querylen)
 {
 #if USE_PGSQL
 	{
 		ExecStatusType q_rv = PGRES_COMMAND_OK;
 		PGresult *result = NULL;
 
-		result = PQexec(sql, query);
+		result = PQexec(sqlConn, query);
 		q_rv = PQresultStatus(result);
 
 		if (q_rv == PGRES_COMMAND_OK)
@@ -266,13 +266,13 @@ sql_nrquery(SQL *sql, const char *query, size_t querylen)
 		}
 		else
 		{
-			/* WarnSQL(sql, _("%s: error during query"), PQresStatus(PQresultStatus(result))); */
+			/* WarnSQL(sqlConn, _("%s: error during query"), PQresStatus(PQresultStatus(result))); */
 			PQclear(result);
 			return (-1);
 		}
 	}
 #else
-	if (mysql_real_query(sql, query, querylen))
+	if (mysql_real_query(sqlConn, query, querylen))
 		return (-1);
 #endif
 
@@ -286,7 +286,7 @@ sql_nrquery(SQL *sql, const char *query, size_t querylen)
 	Returns a query's result, or NULL on error.
 **************************************************************************************************/
 SQL_RES *
-sql_query(SQL *sql, const char *query, size_t querylen)
+sql_query(SQL *sqlConn, const char *query, size_t querylen)
 {
 	SQL_RES *res = NULL;
 
@@ -295,7 +295,7 @@ sql_query(SQL *sql, const char *query, size_t querylen)
 		ExecStatusType q_rv = PGRES_COMMAND_OK;
 		PGresult *result = NULL;
 
-		result = PQexec(sql, query);
+		result = PQexec(sqlConn, query);
 		q_rv = PQresultStatus(result);
 
 		if (q_rv == PGRES_TUPLES_OK)
@@ -323,13 +323,13 @@ sql_query(SQL *sql, const char *query, size_t querylen)
 		}
 		else
 		{
-			/* WarnSQL(sql, _("%s: error during query"), PQresStatus(PQresultStatus(result))); */
+			/* WarnSQL(sqlConn, _("%s: error during query"), PQresStatus(PQresultStatus(result))); */
 			PQclear(result);
 			return (NULL);
 		}
 	}
 #else
-	if (mysql_real_query(sql, query, querylen) || !(res = mysql_store_result(sql)))
+	if (mysql_real_query(sqlConn, query, querylen) || !(res = mysql_store_result(sqlConn)))
 		return (NULL);
 #endif
 
@@ -343,7 +343,7 @@ sql_query(SQL *sql, const char *query, size_t querylen)
 	Like sql_query, but accepts varargs format.
 **************************************************************************************************/
 SQL_RES *
-sql_queryf(SQL *sql, const char *fmt, ...)
+sql_queryf(SQL *sqlConn, const char *fmt, ...)
 {
 	va_list ap;
 	char buf[DNS_QUERYBUFSIZ];
@@ -353,7 +353,7 @@ sql_queryf(SQL *sql, const char *fmt, ...)
 	buflen = vsnprintf(buf, sizeof(buf), fmt, ap);
 	va_end(ap);
 
-	return sql_query(sql, buf, buflen);
+	return sql_query(sqlConn, buf, buflen);
 }
 /*--- sql_queryf() ------------------------------------------------------------------------------*/
 
@@ -364,7 +364,7 @@ sql_queryf(SQL *sql, const char *fmt, ...)
 	occurred.
 **************************************************************************************************/
 long
-sql_count(SQL *sql, const char *fmt, ...)
+sql_count(SQL *sqlConn, const char *fmt, ...)
 {
 	va_list ap;
 	char buf[DNS_QUERYBUFSIZ];
@@ -376,7 +376,7 @@ sql_count(SQL *sql, const char *fmt, ...)
 	buflen = vsnprintf(buf, sizeof(buf), fmt, ap);
 	va_end(ap);
 
-	if (!(res = sql_query(sql, buf, buflen)))
+	if (!(res = sql_query(sqlConn, buf, buflen)))
 		return (-1);
 	if (sql_num_rows(res))
 #if USE_PGSQL
@@ -439,12 +439,12 @@ sql_getrow(SQL_RES *res)
 	Escapes a string to make it suitable for an SQL query.
 **************************************************************************************************/
 void
-sql_escstr(SQL *sql, char *dest, char *src, size_t srclen)
+sql_escstr(SQL *sqlConn, char *dest, char *src, size_t srclen)
 {
 #if USE_PGSQL
 	PQescapeString(dest, src, srclen);
 #else
-	mysql_real_escape_string(sql, dest, src, srclen);
+	mysql_real_escape_string(sqlConn, dest, src, srclen);
 #endif
 }
 /*--- sql_escstr() ------------------------------------------------------------------------------*/
