@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/axfr.c,v 1.34 2005/01/13 19:54:46 bboy Exp $
+	$Id: axfr.c,v 1.38 2005/04/29 16:10:27 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -46,7 +46,7 @@ axfr_error(TASK *t, const char *fmt, ...)
 	va_end(ap);
 
 	if (t)
-		task_output_info(t);
+		task_output_info(t, NULL);
 	else
 		Warnx("%s", msg);
 
@@ -100,7 +100,8 @@ axfr_write_wait(TASK *t)
 static void
 axfr_write(TASK *t, char *buf, size_t size)
 {
-	int rv, offset = 0;
+	int		rv;
+	size_t	offset = 0;
 
 	do
 	{
@@ -215,11 +216,6 @@ check_xfer(TASK *t, MYDNS_SOA *soa)
 static void
 axfr_zone(TASK *t, MYDNS_SOA *soa)
 {
-	SQL_RES	*res = NULL;
-	SQL_ROW	row;
-	char		query[256];
-	size_t	querylen;
-
 #if DEBUG_ENABLED && DEBUG_AXFR
 	Debug("%s: Beginning zone transfer", desctask(t));
 #endif
@@ -242,73 +238,39 @@ axfr_zone(TASK *t, MYDNS_SOA *soa)
 	*/
 	if (soa->id)
 	{
-#define BETTER_RR_LOAD 1
-#if BETTER_RR_LOAD
-		MYDNS_RR *RR = NULL, *rr;
+		MYDNS_RR *ThisRR = NULL, *rr;
 
-		if (mydns_rr_load(sql, &RR, soa->id, DNS_QTYPE_ANY, NULL, soa->origin) == 0)
+		if (mydns_rr_load(sql, &ThisRR, soa->id, DNS_QTYPE_ANY, NULL, soa->origin) == 0)
 		{
-			for (rr = RR; rr; rr = rr->next)
+			for (rr = ThisRR; rr; rr = rr->next)
 			{
 				int len;
 
-				/* Put origin into 'name' if 'name' is empty */
+#if DEBUG_ENABLED && DEBUG_AXFR
+				Debug("%s: Examining rr->name '%s'", desctask(t), rr->name);
+#endif
+
+				/* If 'name' doesn't end with a dot, append the origin */
 				len = strlen(rr->name);
 				if (rr->name[len-1] != '.')
 				{
+#if DEBUG_ENABLED && DEBUG_AXFR
+					Debug("%s: Appending origin for name '%s'", desctask(t), rr->name);
+#endif
 					if (*rr->name)
 						strcat(rr->name, ".");
 					strncat(rr->name, soa->origin, sizeof(rr->name) - len - 1);
+#if DEBUG_ENABLED && DEBUG_AXFR
+					Debug("%s: rr->name is now '%s'", desctask(t), rr->name);
+#endif
 				}
 
 				/* Transmit this resource record */
 				rrlist_add(t, ANSWER, DNS_RRTYPE_RR, (void *)rr, rr->name);
 				axfr_reply(t);
 			}
-			mydns_rr_free(RR);
+			mydns_rr_free(ThisRR);
 		}
-#else
-		querylen = snprintf(query, sizeof(query),
-			"SELECT "MYDNS_RR_FIELDS" FROM %s WHERE zone=%u%s",
-			mydns_rr_table_name, soa->id, mydns_rr_use_active ? " AND active=1" : "");
-		if (!(res = sql_query(sql, query, querylen)))
-			ErrSQL(sql, "%s: %s", desctask(t), _("error loading resource records"));
-
-		/* For each RR, send one message */
-		while ((row = sql_getrow(res)))
-		{
-			MYDNS_RR *rr;
-			int len;
-
-			if (!(rr = mydns_parse_rr(row, soa->origin)))
-				continue;
-			len = strlen(rr->name);
-			if (rr->name[len-1] != '.')
-			{
-				if (*rr->name)
-					strcat(rr->name, ".");
-				strncat(rr->name, soa->origin, sizeof(rr->name) - len - 1);
-			}
-
-			/* Append origin to data for certain types */
-			switch (rr->type)
-			{
-				case DNS_QTYPE_CNAME:
-				case DNS_QTYPE_NS:
-				case DNS_QTYPE_MX:
-					len = strlen(rr->data);
-					if (rr->data[len-1] != '.')
-						strncat(rr->data, soa->origin, sizeof(rr->data) - len - 1);
-					break;
-				default:
-					break;
-			}
-			rrlist_add(t, ANSWER, DNS_RRTYPE_RR, (void *)rr, rr->name);
-			axfr_reply(t);
-			mydns_rr_free(rr);
-		}
-		sql_free(res);
-#endif
 	}
 
 	/* Send closing SOA record */
@@ -391,7 +353,7 @@ axfr(TASK *t)
 #endif
 	t->qdcount = 1;
 	t->an.size = total_records;
-	task_output_info(t);
+	task_output_info(t, NULL);
 
 	sockclose(t->fd);
 
