@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/cache.c,v 1.100 2005/01/13 19:54:46 bboy Exp $
+	$Id: cache.c,v 1.103 2005/04/20 17:14:15 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -46,11 +46,11 @@ extern char	*dn_default_ns;						/* Default NS for directNIC */
 static int
 isprime(unsigned int number)
 {
-	register unsigned int div = 3;
+	register unsigned int divn = 3;
 
-	while (div * div < number && number % div != 0)
-		div += 2;
-	return (number % div != 0);
+	while (divn * divn < number && number % divn != 0)
+		divn += 2;
+	return (number % divn != 0);
 }
 /*--- isprime() ---------------------------------------------------------------------------------*/
 #endif
@@ -66,7 +66,7 @@ _cache_init(uint32_t limit, uint32_t expire, const char *desc)
 	CACHE *C;
 
 	if (!(C = calloc(1, sizeof(CACHE))))
-		Err("calloc");
+		Err(_("out of memory"));
 	C->limit = limit;
 	C->expire = expire;
 
@@ -110,7 +110,7 @@ _cache_init(uint32_t limit, uint32_t expire, const char *desc)
 #endif
 
 	if (!(C->nodes = calloc(C->slots, sizeof(CNODE *))))
-		Err("calloc");
+		Err(_("out of memory"));
 
 #if DEBUG_ENABLED && DEBUG_CACHE
 #if (HASH_TYPE == ORIGINAL_HASH)
@@ -252,25 +252,25 @@ cache_status(CACHE *C)
 	Adds the specified node to the head of the MRU list.
 **************************************************************************************************/
 static void
-mrulist_add(CACHE *Cache, CNODE *n)
+mrulist_add(CACHE *ThisCache, CNODE *n)
 {
-	register CNODE *head = Cache->mruHead;
+	register CNODE *head = ThisCache->mruHead;
 
-	if (!n || !Cache) return;
+	if (!n || !ThisCache) return;
 
-	if (!Cache->mruHead)
+	if (!ThisCache->mruHead)
 	{
-		Cache->mruHead = n;
-		Cache->mruHead->mruPrev = NULL;
-		Cache->mruHead->mruNext = NULL;
-		Cache->mruTail = n;
+		ThisCache->mruHead = n;
+		ThisCache->mruHead->mruPrev = NULL;
+		ThisCache->mruHead->mruNext = NULL;
+		ThisCache->mruTail = n;
 	}
 	else
 	{
 		n->mruNext = head;
 		n->mruPrev = head->mruPrev;
 		if (head->mruPrev == NULL)
-			Cache->mruHead = n;
+			ThisCache->mruHead = n;
 		else
 			head->mruPrev->mruNext = n;
 		head->mruPrev = n;
@@ -283,15 +283,15 @@ mrulist_add(CACHE *Cache, CNODE *n)
 	MRULIST_DEL
 **************************************************************************************************/
 static void
-mrulist_del(CACHE *Cache, CNODE *n)
+mrulist_del(CACHE *ThisCache, CNODE *n)
 {
-	if (!n || !Cache || !Cache->mruHead) return;
+	if (!n || !ThisCache || !ThisCache->mruHead) return;
 
-	if (n == Cache->mruHead)
+	if (n == ThisCache->mruHead)
 	{
-		Cache->mruHead = n->mruNext;
-		if (Cache->mruHead == NULL)
-			Cache->mruTail = NULL;
+		ThisCache->mruHead = n->mruNext;
+		if (ThisCache->mruHead == NULL)
+			ThisCache->mruTail = NULL;
 		else
 			n->mruNext->mruPrev = NULL;
 	}
@@ -299,7 +299,7 @@ mrulist_del(CACHE *Cache, CNODE *n)
 	{
 		n->mruPrev->mruNext = n->mruNext;
 		if (n->mruNext == NULL)
-			Cache->mruTail = n->mruPrev;
+			ThisCache->mruTail = n->mruPrev;
 		else
 			n->mruNext->mruPrev = n->mruPrev;
 	}
@@ -312,19 +312,19 @@ mrulist_del(CACHE *Cache, CNODE *n)
 	Frees the node specified and removes it from the cache.
 **************************************************************************************************/
 static void
-cache_free_node(CACHE *Cache, uint32_t hash, CNODE *n)
+cache_free_node(CACHE *ThisCache, uint32_t hash, CNODE *n)
 {
 	register CNODE *prev = NULL, *cur, *next;
 
-	if (!n || hash >= Cache->slots)
+	if (!n || hash >= ThisCache->slots)
 		return;
 
-	for (cur = Cache->nodes[hash]; cur; cur = next)
+	for (cur = ThisCache->nodes[hash]; cur; cur = next)
 	{
 		next = cur->next_node;
 		if (cur == n)		/* Delete this node */
 		{
-			mrulist_del(Cache, n);								/* Remove from MRU/LRU list */
+			mrulist_del(ThisCache, n);							/* Remove from MRU/LRU list */
 
 			/* Remove the node */
 			if (cur->datalen)
@@ -340,13 +340,13 @@ cache_free_node(CACHE *Cache, uint32_t hash, CNODE *n)
 				mydns_rr_free((MYDNS_RR *)cur->data);
 			}
 
-			if (cur == Cache->nodes[hash])					/* Head of node? */
-				Cache->nodes[hash] = cur->next_node;
+			if (cur == ThisCache->nodes[hash])				/* Head of node? */
+				ThisCache->nodes[hash] = cur->next_node;
 			else if (prev)
 				prev->next_node = cur->next_node;
 			Free(cur);
-			Cache->out++;
-			Cache->count--;
+			ThisCache->out++;
+			ThisCache->count--;
 			return;
 		}
 		else
@@ -362,19 +362,19 @@ cache_free_node(CACHE *Cache, uint32_t hash, CNODE *n)
 	Deletes all nodes within the cache.
 **************************************************************************************************/
 void
-cache_empty(CACHE *Cache)
+cache_empty(CACHE *ThisCache)
 {
 	register int ct;
 	register CNODE *n, *tmp;
 
-	if (!Cache) return;
-	for (ct = 0; ct < Cache->slots; ct++)
-		for (n = Cache->nodes[ct]; n; n = tmp)
+	if (!ThisCache) return;
+	for (ct = 0; ct < ThisCache->slots; ct++)
+		for (n = ThisCache->nodes[ct]; n; n = tmp)
 		{
 			tmp = n->next_node;
-			cache_free_node(Cache, ct, n);
+			cache_free_node(ThisCache, ct, n);
 		}
-	Cache->mruHead = Cache->mruTail = NULL;
+	ThisCache->mruHead = ThisCache->mruTail = NULL;
 }
 /*--- cache_empty() -----------------------------------------------------------------------------*/
 
@@ -384,33 +384,56 @@ cache_empty(CACHE *Cache)
 	Deletes all expired nodes within the cache.
 **************************************************************************************************/
 void
-cache_cleanup(CACHE *Cache)
+cache_cleanup(CACHE *ThisCache)
 {
 	register int	ct;
 	register CNODE	*n, *tmp;
 
-	if (!Cache)
+	if (!ThisCache)
 		return;
-	for (ct = 0; ct < Cache->slots; ct++)
-		for (n = Cache->nodes[ct]; n; n = tmp)
+	for (ct = 0; ct < ThisCache->slots; ct++)
+		for (n = ThisCache->nodes[ct]; n; n = tmp)
 		{
 			tmp = n->next_node;
 			if (n->expire && (current_time > n->expire))
 			{
-				Cache->expired++;
-				cache_free_node(Cache, ct, n);
+				ThisCache->expired++;
+				cache_free_node(ThisCache, ct, n);
 			}
 		}
 }
 /*--- cache_cleanup() ---------------------------------------------------------------------------*/
 
 
+/**************************************************************************************************
+	CACHE_PURGE_ZONE
+	Deletes all nodes within the cache for the specified zone.
+**************************************************************************************************/
+void
+cache_purge_zone(CACHE *ThisCache, uint32_t zone)
+{
+	register int	ct;
+	register CNODE	*n, *tmp;
+
+	if (!ThisCache)
+		return;
+	for (ct = 0; ct < ThisCache->slots; ct++)
+		for (n = ThisCache->nodes[ct]; n; n = tmp)
+		{
+			tmp = n->next_node;
+			if (n->zone == zone)
+				cache_free_node(ThisCache, ct, n);
+		}
+}
+/*--- cache_purge_zone() ------------------------------------------------------------------------*/
+
+
 /**************************************************************************************************
 	CACHE_HASH
 	Returns hash value.
 **************************************************************************************************/
 static inline uint32_t
-cache_hash(CACHE *Cache, uint32_t initval, void *buf, register size_t buflen)
+cache_hash(CACHE *ThisCache, uint32_t initval, void *buf, register size_t buflen)
 #if (HASH_TYPE == ORIGINAL_HASH)
 {
 	register uint32_t	hash;
@@ -427,7 +450,7 @@ cache_hash(CACHE *Cache, uint32_t initval, void *buf, register size_t buflen)
 			hash = hash ^ tmp;
 		}
 	}
-	return (hash % Cache->slots);
+	return (hash % ThisCache->slots);
 }
 #elif (HASH_TYPE == ADDITIVE_HASH)
 {
@@ -436,7 +459,7 @@ cache_hash(CACHE *Cache, uint32_t initval, void *buf, register size_t buflen)
 
 	for (hash = initval, p = (unsigned char *)buf; p < (unsigned char *)(buf + buflen); p++)
 		hash += *p;
-	return (hash % Cache->slots);
+	return (hash % ThisCache->slots);
 }
 #elif (HASH_TYPE == ROTATING_HASH)
 {
@@ -445,7 +468,7 @@ cache_hash(CACHE *Cache, uint32_t initval, void *buf, register size_t buflen)
 
 	for (hash = initval, p = (unsigned char *)buf; p < (unsigned char *)(buf + buflen); p++)
 		hash = (hash << 4) ^ (hash >> 28) ^ (*p);
-	return ((hash ^ (hash>>10) ^ (hash>>20)) & Cache->mask);
+	return ((hash ^ (hash>>10) ^ (hash>>20)) & ThisCache->mask);
 }
 #elif (HASH_TYPE == FNV_HASH)
 {
@@ -461,10 +484,10 @@ cache_hash(CACHE *Cache, uint32_t initval, void *buf, register size_t buflen)
 	hash *= FNV_32_PRIME;
 	hash ^= (uint32_t)initval;
 
-	if (Cache->bits == 16)
+	if (ThisCache->bits == 16)
 		return ((hash >> 16) ^ (hash & (((uint32_t)1 << 16) - 1)));
 	else
-		return (hash % Cache->slots);
+		return (hash % ThisCache->slots);
 }
 #else
 #	error Hash method unknown or unspecified
@@ -651,7 +674,7 @@ zone_cache_find(TASK *t, uint32_t zone, char *origin, dns_qtype_t type,
 	/* Add to cache */
 	C->in++;
 	if (!(n = calloc(1, sizeof(CNODE))))
-		Err("calloc");
+		Err(_("out of memory"));
 	n->hash = hash;
 	n->zone = zone;
 	n->type = type;
@@ -748,7 +771,7 @@ reply_cache_find(TASK *t)
 				/* Allocate space for reply data */
 				t->replylen = n->datalen - sizeof(DNS_HEADER) - sizeof(task_error_t);
 				if (!(t->reply = malloc(t->replylen)))
-					Err("malloc");
+					Err(_("out of memory"));
 				p = n->data;
 
 				/* Copy DNS header */
@@ -768,6 +791,8 @@ reply_cache_find(TASK *t)
 				DNS_GET16(t->ns.size, p);
 				DNS_GET16(t->ar.size, p);
 
+				t->zone = n->zone;
+
 				t->reply_from_cache = 1;
 				ReplyCache->hits++;
 #if DEBUG_ENABLED && DEBUG_CACHE
@@ -866,9 +891,9 @@ add_reply_to_cache(TASK *t)
 	ReplyCache->in++;
 
 	if (!(n = calloc(1, sizeof(CNODE))))
-		Err("calloc");
+		Err(_("out of memory"));
 	n->hash = hash;
-	n->zone = 0;
+	n->zone = t->zone;
 	n->type = t->qtype;
 	n->protocol = t->protocol;
 	memcpy(n->name, t->qd, t->qdlen);
@@ -877,7 +902,7 @@ add_reply_to_cache(TASK *t)
 	/* The data is the DNS_HEADER, the reason, then the reply */
 	n->datalen = sizeof(DNS_HEADER) + sizeof(task_error_t) + t->replylen;
 	if (!(n->data = malloc(n->datalen)))
-		Err("malloc");
+		Err(_("out of memory"));
 	p = n->data;
 
 	/* Save DNS header */
