@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/cache.h,v 1.50 2005/01/13 19:54:46 bboy Exp $
+	$Id: cache.h,v 1.53 2005/04/20 17:14:15 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -105,7 +105,8 @@ extern CACHE *NegativeCache;						/* Negative zone cache */
 #endif
 
 extern void cache_status(CACHE *);
-extern void cache_init(), cache_empty(CACHE *), cache_cleanup(CACHE *);
+extern void cache_init(void), cache_empty(CACHE *), cache_cleanup(CACHE *);
+extern void	cache_purge_zone(CACHE *, uint32_t);
 extern void *zone_cache_find(TASK *, uint32_t, char *, dns_qtype_t, char *, size_t, int *, MYDNS_SOA *);
 
 extern int	reply_cache_find(TASK *);
