@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/conf.c,v 1.53 2005/01/13 19:54:46 bboy Exp $
+	$Id: conf.c,v 1.58 2005/04/21 17:17:24 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -35,6 +35,7 @@ gid_t		perms_gid = 0;											/* Group permissions */
 time_t	task_timeout;											/* Task timeout */
 int		axfr_enabled = 0;										/* Enable AXFR? */
 int		tcp_enabled = 0;										/* Enable TCP? */
+int		dns_update_enabled = 0;								/* Enable DNS UPDATE? */
 int		ignore_minimum = 0;									/* Ignore minimum TTL? */
 
 int		forward_recursive = 0;								/* Forward recursive queries? */
@@ -51,9 +52,13 @@ char		*dn_default_ns = NULL;								/* Default NS for directNIC */
 #endif
 
 
-/* Default config values */
+/*
+**  Default config values
+**
+**  If the 'name' is "-", the --dump-config option treats 'desc' as a header field.
+*/
 static CONF defConfig[] = {
-/* Name						Value							Description	*/
+/* name						value							desc	*/
 {	"-",						NULL,							N_("DATABASE INFORMATION")},
 {	"db-host",				"localhost",				N_("SQL server hostname")},
 {	"db-user",				"username",					N_("SQL server username")},
@@ -86,6 +91,7 @@ static CONF defConfig[] = {
 {	"recursive",			"",							N_("Location of recursive resolver")},
 {	"allow-axfr",			"no",							N_("Should AXFR be enabled?")},
 {	"allow-tcp",			"no",							N_("Should TCP be enabled?")},
+{	"allow-update",		"no",							N_("Should DNS UPDATE be enabled?")},
 {	"ignore-minimum",		"no",							N_("Ignore minimum TTL for zone?")},
 {	"soa-table",			MYDNS_SOA_TABLE,			N_("Name of table containing SOA records")},
 {	"rr-table",				MYDNS_RR_TABLE,			N_("Name of table containing RR data")},
@@ -171,10 +177,10 @@ dump_config(void)
 			continue;
 		}
 
-		if (!c->value || !c->value[0])
-			continue;
 		if (!value)
 		{
+			if (!c->value || !c->value[0])
+				continue;
 			value = c->value;
 			defaulted = 1;
 		}
@@ -397,11 +403,12 @@ load_config(void)
 	/* Set default for database username to real username if none was provided */
 	if (!conf_get(&Conf, "db-user", NULL))
 	{
-		struct passwd *pwd;
-		if ((pwd = getpwuid(getuid())) && pwd->pw_name)
+		struct passwd *pwd2;
+
+		if ((pwd2 = getpwuid(getuid())) && pwd2->pw_name)
 		{
-			conf_set(&Conf, "db-user", pwd->pw_name, 0);
-			memset(pwd, 0, sizeof(struct passwd));
+			conf_set(&Conf, "db-user", pwd2->pw_name, 0);
+			memset(pwd2, 0, sizeof(struct passwd));
 		}
 	}
 #endif
@@ -432,6 +439,7 @@ load_config(void)
 	task_timeout = atou(conf_get(&Conf, "timeout", NULL));
 	axfr_enabled = GETBOOL(conf_get(&Conf, "allow-axfr", NULL));
 	tcp_enabled = GETBOOL(conf_get(&Conf, "allow-tcp", NULL));
+	dns_update_enabled = GETBOOL(conf_get(&Conf, "allow-update", NULL));
 
 	ignore_minimum = GETBOOL(conf_get(&Conf, "ignore-minimum", NULL));
 
@@ -441,7 +449,7 @@ load_config(void)
 
 	/* Set additional where clauses if provided */
 	mydns_set_soa_where_clause(conf_get(&Conf, "soa-where", NULL));
-	mydns_set_rr_where_clause(conf_get(&Conf, "soa-where", NULL));
+	mydns_set_rr_where_clause(conf_get(&Conf, "rr-where", NULL));
 
 	/* Set recursive server if specified */
 	conf_set_recursive();
