@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/db.c,v 1.38 2005/01/13 19:54:46 bboy Exp $
+	$Id: db.c,v 1.43 2006/01/18 20:46:47 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -21,7 +21,7 @@
 #include "named.h"
 
 /* Make this nonzero to enable debugging for this source file */
-#define	DEBUG_DB	0
+#define	DEBUG_DB	1
 
 
 /**************************************************************************************************
@@ -113,7 +113,7 @@ db_output_create_tables(void)
 #if ALIAS_ENABLED
 		printf("OR type='ALIAS' ");
 #endif
-		printf("OR type='CNAME' OR type='HINFO' OR type='MX' OR type='NS' ");
+		printf("OR type='CNAME' OR type='HINFO' OR type='MX' OR type='NAPTR' OR type='NS' ");
 		printf("OR type='PTR' OR type='RP' OR type='SRV' OR type='TXT'),\n");
 	printf("  data   VARCHAR(128) NOT NULL,\n");
 	printf("  aux    INTEGER NOT NULL default 0,\n");
@@ -130,7 +130,7 @@ db_output_create_tables(void)
 #if ALIAS_ENABLED
 		printf("'ALIAS',");
 #endif
-		printf("'CNAME','HINFO','MX','NS','PTR','RP','SRV','TXT'),\n");
+		printf("'CNAME','HINFO','MX','NAPTR','NS','PTR','RP','SRV','TXT'),\n");
 	printf("  data       CHAR(128) NOT NULL,\n");
 	printf("  aux        INT UNSIGNED NOT NULL,\n");
 	printf("  ttl        INT UNSIGNED NOT NULL default '%u',\n", DNS_DEFAULT_TTL);
@@ -226,6 +226,7 @@ db_check_optional(void)
 {
 	int old_soa_use_active = mydns_soa_use_active;
 	int old_soa_use_xfer = mydns_soa_use_xfer;
+	int old_soa_use_update_acl = mydns_soa_use_update_acl;
 	int old_rr_use_active = mydns_rr_use_active;
 
 	/* Check for soa.active */
@@ -238,6 +239,11 @@ db_check_optional(void)
 	if (mydns_soa_use_xfer != old_soa_use_xfer)
 		Verbose(_("optional 'xfer' column found in '%s' table"), mydns_soa_table_name);
 
+	/* Check for soa.update_acl */
+	mydns_set_soa_use_update_acl(sql);
+	if (mydns_soa_use_update_acl != old_soa_use_update_acl)
+		Verbose(_("optional 'update_acl' column found in '%s' table"), mydns_soa_table_name);
+
 	/* Check for rr.active */
 	mydns_set_rr_use_active(sql);
 	if (mydns_rr_use_active != old_rr_use_active)
