@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/encode.c,v 1.32 2005/01/13 19:54:46 bboy Exp $
+	$Id: encode.c,v 1.36 2006/01/18 20:46:47 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -21,10 +21,10 @@
 #include "named.h"
 
 /* Make this nonzero to enable debugging for this source file */
-#define	DEBUG_ENCODE	0
+#define	DEBUG_ENCODE	1
 
 /* Set this to nonzero to disable encoding */
-#define	NO_ENCODING 0
+#define	NO_ENCODING		0
 
 
 /**************************************************************************************************
@@ -41,24 +41,24 @@ name_remember(TASK *t, char *name, unsigned int offset)
 	if (!t->Names)
 	{
 		if (!(t->Names = (char **)malloc(1 * sizeof(char *))))
-			Err("malloc");
+			Err(_("out of memory"));
 	}
 	else
 	{
 		if (!(t->Names = realloc(t->Names, (t->numNames + 1) * sizeof(char *))))
-			Err("realloc");
+			Err(_("out of memory"));
 	}
 	if (!(t->Names[t->numNames] = strdup(name)))
 		Err("strdup");
 	if (!t->Offsets)
 	{
 		if (!(t->Offsets = malloc(sizeof(unsigned int))))
-			Err("malloc");
+			Err(_("out of memory"));
 	}
 	else
 	{
 		if (!(t->Offsets = realloc(t->Offsets, (t->numNames + 1) * sizeof(unsigned int))))
-			Err("realloc");
+			Err(_("out of memory"));
 	}
 #else
 	if (t->numNames >= MAX_STORED_NAMES - 1)
