@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/error.c,v 1.26 2005/01/13 19:54:46 bboy Exp $
+	$Id: error.c,v 1.29 2005/04/20 16:49:12 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -57,6 +57,10 @@ err_reason_str(TASK *t, task_error_t reason)
 		case ERR_TIMEOUT: return ((char *)_("Communications_timeout"));
 		case ERR_BROKEN_GLUE: return ((char *)_("Malformed_glue"));
 		case ERR_INVALID_ADDRESS: return ((char *)_("Invalid_address"));
+		case ERR_INVALID_TYPE: return ((char *)_("Invalid_type"));
+		case ERR_INVALID_CLASS: return ((char *)_("Invalid_class"));
+		case ERR_INVALID_TTL: return ((char *)_("Invalid_TTL"));
+		case ERR_INVALID_DATA: return ((char *)_("Invalid_data"));
 		case ERR_DB_ERROR: return ((char *)_("Database_error"));
 		case ERR_NO_QUESTION: return ((char *)_("No_question_in_query"));
 		case ERR_MULTI_QUESTIONS: return ((char *)_("Multiple_questions_in_query"));
@@ -64,11 +68,14 @@ err_reason_str(TASK *t, task_error_t reason)
 		case ERR_UNSUPPORTED_OPCODE:
 			snprintf(buf, sizeof(buf), "%s_%s", _("Unsupported_opcode"), mydns_opcode_str(t->hdr.opcode));
 			return buf;
+		case ERR_UNSUPPORTED_TYPE: return ((char *)_("Unsupported_type"));
 		case ERR_MALFORMED_REQUEST: return ((char *)_("Malformed_request"));
 		case ERR_AXFR_NOT_ENABLED: return ((char *)_("AXFR_not_enabled"));
 		case ERR_TCP_NOT_ENABLED: return ((char *)_("TCP_not_enabled"));
 		case ERR_RESPONSE_BIT_SET: return ((char *)_("Response_bit_set_on_query"));
 		case ERR_FWD_RECURSIVE: return ((char *)_("Recursive_query_forwarding_error"));
+		case ERR_NO_UPDATE: return ((char *)_("UPDATE_denied"));
+		case ERR_PREREQUISITE_FAILED: return ((char *)_("UPDATE_prerequisite_failed"));
 	}
 	return ((char *)_("Unknown"));
 }
@@ -105,7 +112,7 @@ _formerr_internal(
 	t->replylen = DNS_HEADERSIZE;
 	dest = t->reply = malloc(t->replylen);
 	if (!t->reply)
-		Err("malloc");
+		Err(_("out of memory"));
 	t->hdr.qr = 1;
 	DNS_PUT16(dest, t->id);										/* Query ID */
 	DNS_PUT(dest, &t->hdr, SIZE16);							/* Header */
