@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/listen.c,v 1.39 2005/01/13 19:54:46 bboy Exp $
+	$Id: listen.c,v 1.42 2006/01/18 20:46:47 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -21,7 +21,7 @@
 #include "named.h"
 
 /* Make this nonzero to enable debugging for this source file */
-#define	DEBUG_LISTEN	0
+#define	DEBUG_LISTEN	1
 
 
 #if HAVE_NET_IF_H
@@ -111,7 +111,8 @@ addrlist_add(int family, void *address, int port)
 		}
 
 	/* Not a duplicate; add new interface */
-	A = calloc(1, sizeof(ADDRLIST));
+	if (!(A = calloc(1, sizeof(ADDRLIST))))
+		Err(_("out of memory"));
 	switch ((A->family = family))
 	{
 		case AF_INET: memcpy(&A->addr4, &addr4, sizeof(struct in_addr)); break;
@@ -260,7 +261,8 @@ addrlist_load(int port)
 
 	for (;;)															/* Allocate buffer space */
 	{
-		buf = malloc(buflen);
+		if (!(buf = malloc(buflen)))
+			Err(_("out of memory"));
 		ifc.ifc_len = buflen;
 		ifc.ifc_buf = buf;
 
@@ -641,13 +643,13 @@ create_listeners(void)
 
 			/* Expand FD lists as appropriate and create listening sockets */
 			if (!(udp4_fd = realloc(udp4_fd, (1 + num_udp4_fd) * sizeof(int))))
-				Err("realloc");
+				Err(_("out of memory"));
 			udp4_fd[num_udp4_fd++] = ipv4_listener(&sa, SOCK_DGRAM);
 
 			if (axfr_enabled || tcp_enabled)
 			{
 				if (!(tcp4_fd = realloc(tcp4_fd, (1 + num_tcp4_fd) * sizeof(int))))
-					Err("realloc");
+					Err(_("out of memory"));
 				tcp4_fd[num_tcp4_fd++] = ipv4_listener(&sa, SOCK_STREAM);
 			}
 		}
@@ -668,13 +670,13 @@ create_listeners(void)
 
 			/* Expand FD lists as appropriate and create listening sockets */
 			if (!(udp6_fd = realloc(udp6_fd, (1 + num_udp6_fd) * sizeof(int))))
-				Err("realloc");
+				Err(_("out of memory"));
 			udp6_fd[num_udp6_fd++] = ipv6_listener(&sa, SOCK_DGRAM);
 
 			if (axfr_enabled || tcp_enabled)
 			{
 				if (!(tcp6_fd = realloc(tcp6_fd, (1 + num_tcp6_fd) * sizeof(int))))
-					Err("realloc");
+					Err(_("out of memory"));
 				tcp6_fd[num_tcp6_fd++] = ipv6_listener(&sa, SOCK_STREAM);
 			}
 		}
