@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/main.c,v 1.119 2005/01/13 19:54:46 bboy Exp $
+	$Id: main.c,v 1.121 2005/04/20 16:49:12 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -580,7 +580,8 @@ spawn_multicpu(void)
 	int n;
 
 	is_master = 1;
-	pidlist = malloc(multicpu * sizeof(pid_t));
+	if (!(pidlist = malloc(multicpu * sizeof(pid_t))))
+		Err(_("out of memory"));
 	for (n = 1; n < multicpu; n++)
 	{
 		pid_t pid;
