@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/named.h,v 1.62 2005/01/13 19:54:46 bboy Exp $
+	$Id: named.h,v 1.65 2005/04/20 16:49:12 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -101,6 +101,7 @@ extern time_t	current_time;									/* Current time */
 extern time_t	task_timeout;									/* Task timeout */
 extern int		axfr_enabled;									/* Allow AXFR? */
 extern int		tcp_enabled;									/* Enable TCP? */
+extern int		dns_update_enabled;							/* Enable DNS UPDATE? */
 extern int		ignore_minimum;								/* Ignore minimum TTL? */
 extern char		hostname[256];									/* This machine's hostname */
 
@@ -214,7 +215,7 @@ extern void		_task_free(TASK *, const char *, int);
 
 
 extern void		task_build_reply(TASK *);
-extern void		task_output_info(TASK *);
+extern void		task_output_info(TASK *, char *);
 extern void		task_process(register TASK *);
 
 
@@ -229,6 +230,9 @@ extern int		read_udp_query(int, int);
 extern void		write_udp_reply(TASK *);
 
 
+/* update.c */
+extern int		dns_update(TASK *);
+
 #endif /* _MYDNS_NAMED_H */
 
 /* vi:set ts=3: */
