@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Id: recursive.c,v 1.7 2005/01/13 19:54:46 bboy Exp $
+	$Id: recursive.c,v 1.8 2005/03/22 17:44:57 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -178,7 +178,7 @@ recursive_fwd_read(TASK *t)
 
 	/* Copy reply into task */
 	if (!(t->reply = malloc(replylen)))
-		Err("malloc");
+		Err(_("out of memory"));
 	memcpy(t->reply, reply, replylen);
 	t->replylen = replylen;
 	r = t->reply;
