@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/reply.c,v 1.57 2005/01/13 19:54:46 bboy Exp $
+	$Id: reply.c,v 1.64 2005/04/29 16:10:27 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -105,12 +105,12 @@ rdata_enlarge(TASK *t, size_t size)
 	if (!t->rdata)
 	{
 		if (!(t->rdata = malloc(t->rdlen)))
-			Err("malloc");
+			Err(_("out of memory"));
 	}
 	else
 	{
 		if (!(t->rdata = realloc(t->rdata, t->rdlen)))
-			Err("realloc");
+			Err(_("out of memory"));
 	}
 	return (t->rdata + t->rdlen - size);
 }
@@ -131,7 +131,9 @@ reply_start_rr(TASK *t, RR *r, char *name, dns_qtype_t type, uint32_t ttl, char
 
 	/* name_encode returns dnserror() */
 	if ((enclen = name_encode(t, enc, name, t->replylen + t->rdlen, 1)) < 0)
-		return rr_error(r->id, "rr %u: %s (%s %s) (name=\"%s\")", r->id, _("invalid name in \"name\""), desc, _("record"), name);
+		return rr_error(r->id, "rr %u: %s (%s %s) (name=\"%s\")", r->id,
+							 _("invalid name in \"name\""), desc, _("record"), name);
+
 	r->length = enclen + SIZE16 + SIZE16 + SIZE32;
 
 	if (!(dest = rdata_enlarge(t, r->length)))
@@ -174,7 +176,8 @@ reply_add_generic_rr(TASK *t, RR *r, char *desc)
 		return (-1);
 
 	if ((enclen = name_encode(t, enc, rr->data, CUROFFSET(t), 1)) < 0)
-		return rr_error(r->id, "rr %u: %s (%s) (data=\"%s\")", r->id, _("invalid name in \"data\""), desc, rr->data);
+		return rr_error(r->id, "rr %u: %s (%s) (data=\"%s\")", r->id,
+							 _("invalid name in \"data\""), desc, rr->data);
 
 	size = enclen;
 	r->length += SIZE16 + size;
@@ -206,7 +209,8 @@ reply_add_a(TASK *t, RR *r)
 	if (inet_pton(AF_INET, rr->data, (void *)&addr) <= 0)
 	{
 		dnserror(t, DNS_RCODE_SERVFAIL, ERR_INVALID_ADDRESS);
-		return rr_error(r->id, "rr %u: %s (A %s) (address=\"%s\")", r->id, _("invalid address in \"data\""), _("record"), rr->data);
+		return rr_error(r->id, "rr %u: %s (A %s) (address=\"%s\")", r->id,
+							 _("invalid address in \"data\""), _("record"), rr->data);
 	}
 	ip = ntohl(addr.s_addr);
 
@@ -250,7 +254,8 @@ reply_add_aaaa(TASK *t, RR *r)
 	if (inet_pton(AF_INET6, rr->data, (void *)&addr) <= 0)
 	{
 		dnserror(t, DNS_RCODE_SERVFAIL, ERR_INVALID_ADDRESS);
-		return rr_error(r->id, "rr %u: %s (AAAA %s) (address=\"%s\")", r->id, _("invalid address in \"data\""), _("record"), rr->data);
+		return rr_error(r->id, "rr %u: %s (AAAA %s) (address=\"%s\")", r->id,
+							 _("invalid address in \"data\""), _("record"), rr->data);
 	}
 
 	if (reply_start_rr(t, r, r->name, DNS_QTYPE_AAAA, rr->ttl, "AAAA") < 0)
@@ -287,7 +292,8 @@ reply_add_hinfo(TASK *t, RR *r)
 	if (hinfo_parse(rr->data, cpu, os, DNS_MAXNAMELEN) < 0)
 	{
 		dnserror(t, DNS_RCODE_SERVFAIL, ERR_RR_NAME_TOO_LONG);
-		return rr_error(r->id, "rr %u: %s (HINFO %s) (data=\"%s\")", r->id, _("name too long in \"data\""), _("record"), rr->data);
+		return rr_error(r->id, "rr %u: %s (HINFO %s) (data=\"%s\")", r->id,
+							 _("name too long in \"data\""), _("record"), rr->data);
 	}
 
 #if DEBUG_ENABLED && DEBUG_REPLY
@@ -339,7 +345,8 @@ reply_add_mx(TASK *t, RR *r)
 		return (-1);
 
 	if ((enclen = name_encode(t, enc, rr->data, CUROFFSET(t) + SIZE16, 1)) < 0)
-		return rr_error(r->id, "rr %u: %s (MX %s) (data=\"%s\")", r->id, _("invalid name in \"data\""), _("record"), rr->data);
+		return rr_error(r->id, "rr %u: %s (MX %s) (data=\"%s\")", r->id,
+							 _("invalid name in \"data\""), _("record"), rr->data);
 
 	size = SIZE16 + enclen;
 	r->length += SIZE16 + size;
@@ -355,6 +362,72 @@ reply_add_mx(TASK *t, RR *r)
 /*--- reply_add_mx() ----------------------------------------------------------------------------*/
 
 
+/**************************************************************************************************
+	REPLY_ADD_NAPTR
+	Adds an NAPTR record to the reply.
+	Returns the numeric offset of the start of this record within the reply, or -1 on error.
+**************************************************************************************************/
+static inline int
+reply_add_naptr(TASK *t, RR *r)
+{
+	MYDNS_RR	*rr = (MYDNS_RR *)r->rr;
+	size_t	flags_len, service_len, regex_len;
+	char		enc[DNS_MAXNAMELEN+1], *dest;
+	int		size, enclen, offset;
+
+#if DEBUG_ENABLED && DEBUG_REPLY
+	Debug("%s: REPLY_ADD: `%s' IN NAPTR `%u %u \"%s\" \"%s\" \"%s\" \"%s\"'", desctask(t),
+			r->name, rr->naptr_order, rr->naptr_pref, rr->naptr_flags, rr->naptr_service,
+			rr->naptr_regex, rr->naptr_replacement);
+#endif
+
+	flags_len = strlen(rr->naptr_flags);
+	service_len = strlen(rr->naptr_service);
+	regex_len = strlen(rr->naptr_regex);
+
+	if (reply_start_rr(t, r, r->name, DNS_QTYPE_NAPTR, rr->ttl, "NAPTR") < 0)
+		return (-1);
+
+	/* We are going to write "something else" and then a name, just like an MX record or something.
+		In this case, though, the "something else" is lots of data.  Calculate the size of
+		"something else" in 'offset' */
+	offset = SIZE16 + SIZE16 + 1 + flags_len + 1 + service_len + 1 + regex_len;
+
+	/* Encode the name at the offset */
+	if ((enclen = name_encode(t, enc, rr->naptr_replacement, CUROFFSET(t) + offset, 1)) < 0)
+		return rr_error(r->id, "rr %u: %s (NAPTR %s) (%s=\"%s\")", r->id,
+							 _("invalid name in \"replacement\""), _("record"), _("replacement"),
+							 rr->naptr_replacement);
+
+	size = offset + enclen;
+	r->length += SIZE16 + size;
+
+	if (!(dest = rdata_enlarge(t, SIZE16 + size)))
+		return dnserror(t, DNS_RCODE_SERVFAIL, ERR_INTERNAL);
+
+	DNS_PUT16(dest, size);
+	DNS_PUT16(dest, (uint16_t)rr->naptr_order);
+	DNS_PUT16(dest, (uint16_t)rr->naptr_pref);
+
+	*dest++ = flags_len;
+	memcpy(dest, rr->naptr_flags, flags_len);
+	dest += flags_len;
+
+	*dest++ = service_len;
+	memcpy(dest, rr->naptr_service, service_len);
+	dest += service_len;
+
+	*dest++ = regex_len;
+	memcpy(dest, rr->naptr_regex, regex_len);
+	dest += regex_len;
+
+	DNS_PUT(dest, enc, enclen);
+
+	return (0);
+}
+/*--- reply_add_naptr() -------------------------------------------------------------------------*/
+
+
 /**************************************************************************************************
 	REPLY_ADD_RP
 	Adds an RP record to the reply.
@@ -379,9 +452,12 @@ reply_add_rp(TASK *t, RR *r)
 		return (-1);
 
 	if ((mboxlen = name_encode(t, encmbox, mbox, CUROFFSET(t), 1)) < 0)
-		return rr_error(r->id, "rr %u: %s (RP %s) (mbox=\"%s\")", r->id, _("invalid name in \"mbox\""), _("record"), mbox);
+		return rr_error(r->id, "rr %u: %s (RP %s) (mbox=\"%s\")", r->id,
+							 _("invalid name in \"mbox\""), _("record"), mbox);
+
 	if ((txtlen = name_encode(t, enctxt, txt, CUROFFSET(t) + mboxlen, 1)) < 0)
-		return rr_error(r->id, "rr %u: %s (RP %s) (txt=\"%s\")", r->id, _("invalid name in \"txt\""), _("record"), txt);
+		return rr_error(r->id, "rr %u: %s (RP %s) (txt=\"%s\")", r->id,
+							 _("invalid name in \"txt\""), _("record"), txt);
 
 	size = mboxlen + txtlen;
 	r->length += SIZE16 + size;
@@ -410,17 +486,19 @@ reply_add_soa(TASK *t, RR *r)
 	MYDNS_SOA	*soa = (MYDNS_SOA *)r->rr;
 
 #if DEBUG_ENABLED && DEBUG_REPLY
-	Debug("%s: REPLY_ADD: `%s' IN SOA", desctask(t), soa->origin);
+	Debug("%s: REPLY_ADD: `%s' IN SOA (mbox=[%s])", desctask(t), soa->origin, soa->mbox);
 #endif
 
 	if (reply_start_rr(t, r, r->name, DNS_QTYPE_SOA, soa->ttl, "SOA") < 0)
 		return (-1);
 
 	if ((nslen = name_encode(t, ns, soa->ns, CUROFFSET(t), 1)) < 0)
-		return rr_error(r->id, "rr %u: %s (SOA %s) (ns=\"%s\")", r->id, _("invalid name in \"ns\""), _("record"), soa->ns);
+		return rr_error(r->id, "rr %u: %s (SOA %s) (ns=\"%s\")", r->id,
+							 _("invalid name in \"ns\""), _("record"), soa->ns);
 
 	if ((mboxlen = name_encode(t, mbox, soa->mbox, CUROFFSET(t) + nslen, 1)) < 0)
-		return rr_error(r->id, "rr %u: %s (SOA %s) (mbox=\"%s\")", r->id, _("invalid name in \"mbox\""), _("record"), soa->mbox);
+		return rr_error(r->id, "rr %u: %s (SOA %s) (mbox=\"%s\")", r->id,
+							 _("invalid name in \"mbox\""), _("record"), soa->mbox);
 
 	size = nslen + mboxlen + (SIZE32 * 5);
 	r->length += SIZE16 + size;
@@ -465,7 +543,8 @@ reply_add_srv(TASK *t, RR *r)
 	/* Arnt Gulbrandsen advises against using compression in the SRV target, although
 		most clients should support it */
 	if ((enclen = name_encode(t, enc, rr->data, CUROFFSET(t) + SIZE16 + SIZE16 + SIZE16, 0)) < 0)
-		return rr_error(r->id, "rr %u: %s (SRV %s) (data=\"%s\")", r->id, _("invalid name in \"data\""), _("record"), rr->data);
+		return rr_error(r->id, "rr %u: %s (SRV %s) (data=\"%s\")", r->id,
+							 _("invalid name in \"data\""), _("record"), rr->data);
 
 	size = SIZE16 + SIZE16 + SIZE16 + enclen;
 	r->length += SIZE16 + size;
@@ -574,6 +653,11 @@ reply_process_rrlist(TASK *t, RRLIST *rrlist)
 								return (-1);
 							break;
 
+						case DNS_QTYPE_NAPTR:
+							if (reply_add_naptr(t, r) < 0)
+								return (-1);
+							break;
+
 						case DNS_QTYPE_NS:
 							if (reply_add_generic_rr(t, r, "NS") < 0)
 								return (-1);
@@ -751,7 +835,7 @@ build_reply(TASK *t, int want_additional)
 	t->replylen = DNS_HEADERSIZE + t->qdlen + t->rdlen;
 	dest = t->reply = malloc(t->replylen);
 	if (!t->reply)
-		Err("malloc");
+		Err(_("out of memory"));
 
 	DNS_PUT16(dest, t->id);										/* Query ID */
 	DNS_PUT(dest, &t->hdr, SIZE16);							/* Header */
