@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/rr.c,v 1.32 2005/01/13 19:54:46 bboy Exp $
+	$Id: rr.c,v 1.35 2005/04/29 15:24:01 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -21,7 +21,7 @@
 #include "named.h"
 
 /* Make this nonzero to enable debugging for this source file */
-#define	DEBUG_RR	1
+#define	DEBUG_RR	0
 
 #if DEBUG_ENABLED && DEBUG_RR
 /* Strings describing the datasections */
@@ -180,7 +180,7 @@ rrlist_add(
 	}
 
 	if (!(new = malloc(sizeof(RR))))
-		Err("malloc");
+		Err(_("out of memory"));
 	new->rrtype = rrtype;
 	switch (new->rrtype)
 	{
