@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/status.c,v 1.10 2005/01/13 19:54:46 bboy Exp $
+	$Id: status.c,v 1.12 2005/04/20 16:49:12 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -42,7 +42,7 @@ status_fake_rr(TASK *t, datasection_t ds, const char *name, const char *fmt, ...
 	va_end(ap);
 
 	if (!(rr = calloc(1, sizeof(MYDNS_RR))))
-		Err("calloc");
+		Err(_("out of memory"));
 	strncpy(rr->name, name, sizeof(rr->name)-1);
 	rr->class = DNS_CLASS_CHAOS;
 	rr->type = DNS_QTYPE_TXT;
