@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/task.c,v 1.76 2005/01/13 19:54:46 bboy Exp $
+	$Id: task.c,v 1.86 2006/01/18 20:50:39 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -38,7 +38,6 @@ int
 new_task(TASK *t, unsigned char *data, size_t len)
 {
 	unsigned char qname[DNS_MAXNAMELEN+1], *src, *qdtop;
-	uint16_t	ancount, nscount, arcount;
 
 #if DEBUG_ENABLED && DEBUG_TASK
 	Debug("new_task(%p, %p, %u)", t, data, len);
@@ -57,9 +56,9 @@ new_task(TASK *t, unsigned char *data, size_t len)
 	DNS_GET16(t->id, src);
 	memcpy(&t->hdr, src, SIZE16); src += SIZE16;
 	DNS_GET16(t->qdcount, src);
-	DNS_GET16(ancount, src);
-	DNS_GET16(nscount, src);
-	DNS_GET16(arcount, src);
+	DNS_GET16(t->ancount, src);
+	DNS_GET16(t->nscount, src);
+	DNS_GET16(t->arcount, src);
 
 	/* Discard queries where the response bit is set; it might be a spoofed packet
 		asking us to talk to ourselves */
@@ -77,22 +76,34 @@ new_task(TASK *t, unsigned char *data, size_t len)
 			t->id, t->hdr.qr, mydns_opcode_str(t->hdr.opcode),
 			t->hdr.aa, t->hdr.tc, t->hdr.rd, t->hdr.ra, t->hdr.z, t->hdr.rcode);
 	Debug("%s: qd=%u an=%u ns=%u ar=%u", desctask(t),
-			t->qdcount, ancount, nscount, arcount);
+			t->qdcount, t->ancount, t->nscount, t->arcount);
 #endif
 
+	/* If 'query' isn't set and this is an UPDATE query, save a copy of the whole query for parsing */
+	if (!t->query && t->hdr.opcode == DNS_OPCODE_UPDATE)
+	{
+		t->len = len;
+		if (!(t->query = malloc(t->len)))
+			Err(_("out of memory"));
+		memcpy(t->query, data, t->len);
+	}
+
 	task_init_header(t);											/* Initialize header fields for reply */
 
 	t->qdlen = len - DNS_HEADERSIZE;							/* Fill in question data */
 	if (t->qdlen <= 0)
 		return formerr(t, DNS_RCODE_FORMERR, ERR_MALFORMED_REQUEST, _("question has zero length"));
-	if (!(t->qd = (char *)malloc(t->qdlen)))
-		Err("malloc");
+	if (!(t->qd = malloc(t->qdlen)))
+		Err(_("out of memory"));
 	memcpy(t->qd, src, t->qdlen);
 	qdtop = src;
 
 	/* Get query name */
 	if (!(src = name_unencode(t->qd, t->qdlen, src, qname, sizeof(qname))))
+	{
+		Warnx("%s: FORMERR in query", desctask(t));
 		return formerr(t, DNS_RCODE_FORMERR, (task_error_t)qname[0], NULL);
+	}
 	strncpy(t->qname, qname, sizeof(t->qname)-1);
 
 	/* Now we have question data, so initialize encoding */
@@ -127,6 +138,10 @@ new_task(TASK *t, unsigned char *data, size_t len)
 	if (t->hdr.tc)
 		return formerr(t, DNS_RCODE_FORMERR, ERR_QUESTION_TRUNCATED, _("query is truncated"));
 
+	/* If DNS updates are enabled and the opcode is UPDATE, do the update */
+	if (dns_update_enabled && t->hdr.opcode == DNS_OPCODE_UPDATE)
+		return dns_update(t);
+
 	/* Server only handles QUERY opcode */
 	if (t->hdr.opcode != DNS_OPCODE_QUERY)
 		return formerr(t, DNS_RCODE_NOTIMP, ERR_UNSUPPORTED_OPCODE, NULL);
@@ -253,7 +268,7 @@ _task_init(
 	TASK *new;
 
 	if (!(new = calloc(1, sizeof(TASK))))
-		Err("calloc");
+		Err(_("out of memory"));
 
 	new->status = status;
 	new->fd = fd;
@@ -348,7 +363,7 @@ task_init_header(TASK *t)
 	TASK_OUTPUT_INFO
 **************************************************************************************************/
 void
-task_output_info(TASK *t)
+task_output_info(TASK *t, char *update_desc)
 {
 #if !DISABLE_DATE_LOGGING
 	struct timeval tv;
@@ -357,6 +372,10 @@ task_output_info(TASK *t)
 	char datebuf[80];
 #endif
 
+	/* If we've already outputted the info for this (i.e. multiple DNS UPDATE requests), ignore */
+	if (t->info_already_out)
+		return;
+
 	/* Don't output anything for TCP sockets in the process of closing */
 	if (t->protocol == SOCK_STREAM && t->fd < 0)
 		return;
@@ -387,7 +406,9 @@ task_output_info(TASK *t)
 		"%d "		/* Authority section */
 		"%d "		/* Additional section */
 		"LOG "
-		"%s"		/* Reply from cache? */
+		"%s "		/* Reply from cache? */
+		"%s "		/* Opcode */
+		"\"%s\""	/* UPDATE description (if any) */
 		,
 #if !DISABLE_DATE_LOGGING
 		datebuf, tv.tv_usec,
@@ -405,7 +426,9 @@ task_output_info(TASK *t)
 		t->an.size,
 		t->ns.size,
 		t->ar.size,
-		(t->reply_from_cache ? "Y" : "N")
+		(t->reply_from_cache ? "Y" : "N"),
+		mydns_opcode_str(t->hdr.opcode),
+		update_desc ? update_desc : ""
 	);
 }
 /*--- task_output_info() ------------------------------------------------------------------------*/
@@ -420,11 +443,16 @@ task_process(register TASK *t)
 {
 	int rv;
 
+
 	/*
 	**  NEED_READ: Need to read query
 	*/
 	if (t->status == NEED_READ)
 	{
+#if DEBUG_ENABLED && DEBUG_TASK
+		Debug("%s: starting task_process() with NEED_READ status", desctask(t));
+#endif
+
 		switch (t->protocol)
 		{
 			case SOCK_DGRAM:
@@ -463,6 +491,10 @@ task_process(register TASK *t)
 	*/
 	if (t->status == NEED_ANSWER)
 	{
+#if DEBUG_ENABLED && DEBUG_TASK
+		Debug("%s: starting task_process() with NEED_ANSWER status", desctask(t));
+#endif
+
 		if (reply_cache_find(t))
 		{
 			char *dest = t->reply;
@@ -492,6 +524,10 @@ task_process(register TASK *t)
 	*/
 	if (t->status == NEED_WRITE)
 	{
+#if DEBUG_ENABLED && DEBUG_TASK
+		Debug("%s: starting task_process() with NEED_WRITE status", desctask(t));
+#endif
+
 		switch (t->protocol)
 		{
 			case SOCK_DGRAM:
@@ -513,6 +549,10 @@ task_process(register TASK *t)
 	*/
 	if (t->status == NEED_RECURSIVE_FWD_CONNECT)
 	{
+#if DEBUG_ENABLED && DEBUG_TASK
+		Debug("%s: starting task_process() with NEED_RECURSIVE_FWD_CONNECT status", desctask(t));
+#endif
+
 		if (recursive_fwd_connect(t) < 0)
 			return dequeue(Tasks, t);
 
@@ -525,11 +565,17 @@ task_process(register TASK *t)
 	*/
 	if (t->status == NEED_RECURSIVE_FWD_WRITE)
 	{
-		int rv = recursive_fwd_write(t);
+		int rv2;
 
-		if (rv < 0)
+#if DEBUG_ENABLED && DEBUG_TASK
+		Debug("%s: starting task_process() with NEED_RECURSIVE_FWD_WRITE status", desctask(t));
+#endif
+
+		rv2 = recursive_fwd_write(t);
+
+		if (rv2 < 0)
 			return dequeue(Tasks, t);
-		else if (rv == 1)				/* 1 means "try again" */
+		else if (rv2 == 1)				/* 1 means "try again" */
 			return;
 
 		/* Forwarded recursive query written successfully */
@@ -541,11 +587,17 @@ task_process(register TASK *t)
 	*/
 	if (t->status == NEED_RECURSIVE_FWD_READ)
 	{
-		int rv = recursive_fwd_read(t);
+		int rv2;
 
-		if (rv < 0)
+#if DEBUG_ENABLED && DEBUG_TASK
+		Debug("%s: starting task_process() with NEED_RECURSIVE_FWD_READ status", desctask(t));
+#endif
+
+		rv2 = recursive_fwd_read(t);
+
+		if (rv2 < 0)
 			return dequeue(Tasks, t);
-		else if (rv == 1)				/* 1 means "try again" */
+		else if (rv2 == 1)				/* 1 means "try again" */
 			return;
 
 		/* Got recursive forwarder's reply; write it to the client */
