@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/task.h,v 1.14 2005/01/13 19:54:46 bboy Exp $
+	$Id: task.h,v 1.18 2005/04/20 16:49:12 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -106,7 +106,10 @@ typedef struct _named_task
 
 	unsigned char	*qd;											/* Question section data */
 	size_t			qdlen;										/* Size of question section */
-	uint16_t			qdcount;										/* "qdcount", from header field */
+	uint16_t			qdcount;										/* "qdcount", from header */
+	uint16_t			ancount;										/* "ancount", from header */
+	uint16_t			nscount;										/* "nscount", from header */
+	uint16_t			arcount;										/* "arcount", from header */
 
 	int				no_markers;									/* Do not use markers? */
 
@@ -121,6 +124,8 @@ typedef struct _named_task
 
 	unsigned int	numNames;									/* Number of names in the list */
 
+	uint32_t			zone;											/* Zone ID */
+
 	uint8_t			sort_level;									/* Current sort level */
 
 	RRLIST			an, ns, ar;									/* RR's for ANSWER, AUTHORITY, ADDITIONAL */
@@ -138,6 +143,9 @@ typedef struct _named_task
 
 	int				forwarded;									/* Forwarded to a recursive server? */
 
+	int				update_done;								/* Did we do any dynamic updates? */
+	int				info_already_out;							/* Has the info already been output? */
+
 	struct _named_task *prev, *next;							/* Pointers to previous/next rec in queue */
 } TASK;
 
