@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/mydns/tcp.c,v 1.43 2005/01/13 19:54:46 bboy Exp $
+	$Id: tcp.c,v 1.47 2005/04/20 17:30:38 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -104,7 +104,7 @@ read_tcp_length(TASK *t)
 		return Warnx("%s: %s (%d octet%s)", clientaddr(t), _("TCP message too long"), t->len, S(t->len));
 
 	if (!(t->query = calloc(1, t->len + 1)))
-		Err("calloc");
+		Err(_("out of memory"));
 	t->offset = 0;
 	return (0);
 }
@@ -197,24 +197,12 @@ write_tcp_reply(TASK *t)
 	/* Write TCP length if we haven't already */
 	if (!t->len_written)
 	{
-		fd_set fds;
-
 		if (write_tcp_length(t) < 0)
 		{
 			dequeue(Tasks, t);
 			return (-1);
 		}
-
-#if 0
-		/* Check for writability on socket.  If it's ready to write, continue writing packet.
-			Otherwise, return and let main handle it until it's ready for write. */
-		FD_ZERO(&fds);
-		FD_SET(t->fd, &fds);
-		if ((select(t->fd + 1, NULL, &fds, NULL, NULL) <= 0) || !FD_ISSET(t->fd, &fds))
-			return (0);
-#else
 		return (0);
-#endif
 	}
 
 	/* Write the reply */
