@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/util/check.c,v 1.32 2005/01/13 19:54:46 bboy Exp $
+	$Id: check.c,v 1.36 2005/05/04 16:49:59 bboy Exp $
+
 	check.c: Check for problems with the data in the database.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -48,8 +49,7 @@ int	syntax_errors, consistency_errors;					/* Number of errors found */
 	Display program usage information.
 **************************************************************************************************/
 static void
-usage(status)
-	int status;
+usage(int status)
 {
 	if (status != EXIT_SUCCESS)
 	{
@@ -93,9 +93,7 @@ usage(status)
 	Process command line options.
 **************************************************************************************************/
 static void
-cmdline(argc, argv)
-	int argc;
-	char *argv[];
+cmdline(int argc, char **argv)
 {
 	char	*optstr;
 	int	optc, optindex;
@@ -252,22 +250,22 @@ check_name_extended(const char *name_in, const char *fqdn, const char *col)
 	Removes the origin from a name if it is present.
 **************************************************************************************************/
 static char *
-shortname(char *name, int empty_name_is_ok)
+shortname(char *name_to_shorten, int empty_name_is_ok)
 {
-	size_t nlen = strlen(name), olen = strlen(soa->origin);
+	size_t nlen = strlen(name_to_shorten), olen = strlen(soa->origin);
 
 	if (nlen < olen)
-		return (name);
-	if (!strcasecmp(soa->origin, name))
+		return (name_to_shorten);
+	if (!strcasecmp(soa->origin, name_to_shorten))
 	{
 		if (empty_name_is_ok)
 			return ("");
 		else
-			return (name);
+			return (name_to_shorten);
 	}
-	if (!strcasecmp(name + nlen - olen, soa->origin))
+	if (!strcasecmp(name_to_shorten + nlen - olen, soa->origin))
 		name[nlen - olen - 1] = '\0';
-	return (name);
+	return (name_to_shorten);
 }
 /*--- shortname() -------------------------------------------------------------------------------*/
 
@@ -436,6 +434,42 @@ check_rr_hinfo(void)
 /*--- check_rr_hinfo() --------------------------------------------------------------------------*/
 
 
+/**************************************************************************************************
+	CHECK_RR_NAPTR
+	Expanded check for NAPTR resource record.
+**************************************************************************************************/
+static void
+check_rr_naptr(void)
+{
+	char tmp[DNS_MAXNAMELEN * 2 + 2], data_copy[DNS_MAXNAMELEN * 2 + 2], *p;
+
+	strncpy(data_copy, rr->data, sizeof(data_copy) - 1);
+	p = data_copy;
+
+	if (!strsep_quotes(&p, tmp, sizeof(tmp)))
+		return rrproblem(_("'order' field missing from NAPTR record"));
+
+	if (!strsep_quotes(&p, tmp, sizeof(tmp)))
+		return rrproblem(_("'preference' field missing from NAPTR record"));
+
+	if (!strsep_quotes(&p, tmp, sizeof(tmp)))
+		return rrproblem(_("'flags' field missing from NAPTR record"));
+
+	if (!strsep_quotes(&p, tmp, sizeof(tmp)))
+		return rrproblem(_("'service' field missing from NAPTR record"));
+
+	if (!strsep_quotes(&p, tmp, sizeof(tmp)))
+		return rrproblem(_("'regexp' field missing from NAPTR record"));
+
+	if (!strsep_quotes(&p, tmp, sizeof(tmp)))
+		return rrproblem(_("'replacement' field missing from NAPTR record"));
+
+	/* For now, don't check 'replacement'.. the example in the RFC even contains illegal chars */
+	/* EXPAND_DATA(tmp); */
+	/* check_name(tmp, "replacement", 1); */
+}
+/*--- check_rr_naptr() --------------------------------------------------------------------------*/
+
 
 /**************************************************************************************************
 	CHECK_RR
@@ -493,6 +527,10 @@ check_rr(void)
 			check_name(data, "rr.data", 1);
 			break;
 
+		case DNS_QTYPE_NAPTR:									/* Data: Multiple fields */
+			check_rr_naptr();
+			break;
+
 		case DNS_QTYPE_NS:										/* Data: Name */
 			EXPAND_DATA(data);
 			check_name(data, "rr.data", 1);
@@ -518,9 +556,11 @@ check_rr(void)
 			break;
 
 		case DNS_QTYPE_TXT:										/* Data: Undefined text string */
+			/* Can be anything, so consider it always OK */
 			break;
 
 		default:
+			rrproblem(_("Unknown/unsupported resource record type"));
 			break;
 	}
 }
@@ -547,7 +587,7 @@ check_zone(void)
 		return;
 	while ((row = sql_getrow(res)))
 	{
-		if (!(rr = mydns_parse_rr(row, soa->origin)))
+		if (!(rr = mydns_rr_parse(row, soa->origin)))
 			continue;
 		check_rr();
 		mydns_rr_free(rr);
@@ -616,9 +656,7 @@ consistency_check(void)
 	MAIN
 **************************************************************************************************/
 int
-main(argc, argv)
-	int argc;
-	const char *argv[];
+main(int argc, char **argv)
 {
 	setlocale(LC_ALL, "");										/* Internationalization */
 	bindtextdomain(PACKAGE, LOCALEDIR);
