@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/util/conf.c,v 1.6 2005/01/13 19:54:46 bboy Exp $
+	$Id: conf.c,v 1.8 2005/04/20 17:22:25 bboy Exp $
+
 	conf.c: Create daemontools service directory for MyDNS.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -30,8 +31,7 @@
 	Display program usage information.
 **************************************************************************************************/
 static void
-usage(status)
-	int status;
+usage(int status)
 {
 	fprintf(stderr, _("Usage: %s logacct /mydns\n"), progname);
 	fprintf(stderr, _("Create daemontools service directory for MyDNS.\n"));
@@ -44,9 +44,7 @@ usage(status)
 	MAIN
 **************************************************************************************************/
 int
-main(argc, argv)
-	int argc;
-	const char *argv[];
+main(int argc, char **argv)
 {
 	const char *loguser;
 	const char *dir;
