@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/util/export.c,v 1.26 2005/01/13 19:54:46 bboy Exp $
+	$Id: export.c,v 1.28 2005/04/28 17:47:27 bboy Exp $
+
 	Outputs zone data in various formats.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -479,7 +480,7 @@ dump_rr_long(MYDNS_SOA *soa)
 	{
 		MYDNS_RR *rr;
 
-		if (!(rr = mydns_parse_rr(row, soa->origin)))
+		if (!(rr = mydns_rr_parse(row, soa->origin)))
 			continue;
 		dump_rr(soa, rr, maxlen);
 		mydns_rr_free(rr);		
