@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/util/import-axfr.c,v 1.17 2005/01/13 19:54:46 bboy Exp $
+	$Id: import-axfr.c,v 1.19 2005/04/20 17:22:25 bboy Exp $
+
 	import-axfr.c: Import DNS data via AXFR.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -29,7 +30,7 @@ static uint32_t got_soa = 0;									/* Have we read the initial SOA record? */
 extern int opt_notrim;											/* Don't remove trailing origin */
 extern int opt_output;											/* Output instead of insert */
 
-extern uint32_t import_soa(const char *origin, const char *ns, const char *mbox,
+extern uint32_t import_soa(const char *import_origin, const char *ns, const char *mbox,
 	unsigned serial, unsigned refresh, unsigned retry, unsigned expire,
 	unsigned minimum, unsigned ttl);
 extern void import_rr(char *name, char *type, char *data, unsigned aux, unsigned ttl);
@@ -44,7 +45,7 @@ static int
 axfr_connect(char *hostportp, char **hostnamep)
 {
 	char		hostport[512];
-	char		*hostname, *portp;
+	char		*rem_hostname, *portp;
 	unsigned int port = 53;
 	int		fd, n;
 	struct hostent	*he;
@@ -52,7 +53,7 @@ axfr_connect(char *hostportp, char **hostnamep)
 
 	strncpy(hostport, hostportp, sizeof(hostport)-1);
 
-	if (!(hostname = hostport) || !*hostname)					/* Parse hostname, port, zone */
+	if (!(rem_hostname = hostport) || !*rem_hostname)	/* Parse hostname, port, zone */
 		Errx(_("host not specified"));
 	if ((portp = strchr(hostport, ':')))
 		*portp++ = '\0', port = atoi(portp);
@@ -66,18 +67,18 @@ axfr_connect(char *hostportp, char **hostnamep)
 	if (strlen(zone) > 256)
 		Errx(_("zone too long"));
 
-	*hostnamep = hostname;
+	*hostnamep = rem_hostname;
 
-	Verbose(_("importing `%s' from %s:%u"), zone, hostname, port);
+	Verbose(_("importing `%s' from %s:%u"), zone, rem_hostname, port);
 
 	memset(&sa, 0, sizeof(struct sockaddr_in));
 	sa.sin_family = AF_INET;
 	sa.sin_port = htons(port);
-	if (!(he = gethostbyname(hostname)))
-		Errx("%s: %s", hostname, _("unknown host"));
+	if (!(he = gethostbyname(rem_hostname)))
+		Errx("%s: %s", rem_hostname, _("unknown host"));
 
 	if ((fd = socket(AF_INET, SOCK_STREAM, 0)) < 0)
-		Err("%s", hostname);
+		Err("%s", rem_hostname);
 
 	for (n = 0; he->h_addr_list[n]; n++)
 	{
@@ -86,7 +87,7 @@ axfr_connect(char *hostportp, char **hostnamep)
 		if (!connect(fd, (const struct sockaddr *)&sa, sizeof(struct sockaddr_in)))
 			return (fd);
 
-		Warn("%s (%s)", hostname, inet_ntoa(sa.sin_addr));
+		Warn("%s (%s)", rem_hostname, inet_ntoa(sa.sin_addr));
 	}
 	close(fd);
 	return (-1);
@@ -158,7 +159,7 @@ make_question(uint16_t id, dns_qtype_t qtype, char *name, size_t *packetlen)
 	Constructs and sends the AXFR request packet.
 **************************************************************************************************/
 static void
-request_axfr(int fd, char *hostname, char *zone)
+request_axfr(int fd, char *rem_hostname, char *zone)
 {
 	char		*qb, *q, *p;
 	size_t	qlen;
@@ -175,7 +176,7 @@ request_axfr(int fd, char *hostname, char *zone)
 	do
 	{
 		if ((rv = write(fd, q + off, qlen - off)) < 0)
-			Err("%s: write", hostname);
+			Err("%s: write", rem_hostname);
 		off += rv;
 	} while (off < qlen);
 	Free(q);
