@@ -1,5 +1,6 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/util/import.c,v 1.25 2005/01/13 19:54:46 bboy Exp $
+	$Id: import.c,v 1.27 2005/04/20 17:22:25 bboy Exp $
+
 	import.c: Import DNS data.
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
@@ -54,8 +55,7 @@ static int	soa_imported, rr_imported, ptr_imported;	/* Number of records importe
 	Display program usage information.
 **************************************************************************************************/
 static void
-usage(status)
-	int status;
+usage(int status)
 {
 	if (status != EXIT_SUCCESS)
 	{
@@ -105,9 +105,7 @@ usage(status)
 	Process command line options.
 **************************************************************************************************/
 static void
-cmdline(argc, argv)
-	int argc;
-	char *argv[];
+cmdline(int argc, char **argv)
 {
 	char	*optstr;
 	int	optc, optindex;
@@ -218,7 +216,7 @@ cmdline(argc, argv)
 	Update, replace, or output SOA.  Returns the zone ID or 1 if not working with database.
 **************************************************************************************************/
 uint32_t
-import_soa(const char *origin, const char *ns, const char *mbox,
+import_soa(const char *import_origin, const char *ns, const char *mbox,
 			  unsigned serial, unsigned refresh, unsigned retry, unsigned expire,
 			  unsigned minimum, unsigned ttl)
 {
@@ -227,19 +225,19 @@ import_soa(const char *origin, const char *ns, const char *mbox,
 	soa_imported++;
 	import_zone_id = 0;
 
-	Verbose("import soa \"%s\"", origin);
+	Verbose("import soa \"%s\"", import_origin);
 
 	if (opt_output)												/* Not updating database */
 	{
 		printf(
 			"soa\t%s\t%s\t%s\t%u\t%u\t%u\t%u\t%u\t%u\n",
-			origin, ns, mbox, serial, refresh, retry, expire, minimum, ttl
+			import_origin, ns, mbox, serial, refresh, retry, expire, minimum, ttl
 		);
 		return (1);
 	}
 
 	/* SQL-escape the strings */
-   sql_escstr(sql, esc_origin, (char *)origin, strlen(origin));
+   sql_escstr(sql, esc_origin, (char *)import_origin, strlen(import_origin));
    sql_escstr(sql, esc_ns, (char *)ns, strlen(ns));
    sql_escstr(sql, esc_mbox, (char *)mbox, strlen(mbox));
 
@@ -251,7 +249,7 @@ import_soa(const char *origin, const char *ns, const char *mbox,
 	{
 		if (!opt_replace)
 		{
-			Warnx("%s: %s", origin, _("zone already exists"));
+			Warnx("%s: %s", import_origin, _("zone already exists"));
 			Errx(_("use -r (--replace) to overwrite existing zone"));
 		}
 		/* Delete from "rr" table */
