@@ -1,5 +1,5 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/util/libptr.c,v 1.6 2005/01/13 19:54:46 bboy Exp $
+	$Id: libptr.c,v 1.8 2005/04/20 17:22:25 bboy Exp $
 
 	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
@@ -36,9 +36,9 @@ int mydns_ptr_use_active = 0;
 	Returns the number of zones in the ptr table.
 **************************************************************************************************/
 long
-mydns_ptr_count(SQL *sql)
+mydns_ptr_count(SQL *sqlConn)
 {
-	return sql_count(sql, "SELECT COUNT(*) FROM %s", mydns_ptr_table_name);
+	return sql_count(sqlConn, "SELECT COUNT(*) FROM %s", mydns_ptr_table_name);
 }
 /*--- mydns_ptr_count() -------------------------------------------------------------------------*/
 
@@ -164,12 +164,12 @@ _mydns_ptr_free(MYDNS_PTR *first)
 /**************************************************************************************************
 	MYDNS_PTR_LOAD
 	Returns 0 on success or nonzero if an error occurred.
+	SQL	*sql;						Open database connection
+	MYDNS_PTR **rptr;				Result list will be returned here
+	struct in_addr *addr;		Look up PTR record for this IP
 **************************************************************************************************/
 int
-mydns_ptr_load(sql, rptr, addr)
-	SQL	*sql;						/* Open database connection */
-	MYDNS_PTR **rptr;				/* Result list will be returned here */
-	struct in_addr *addr;		/* Look up PTR record for this IP */
+mydns_ptr_load(SQL *sqlConn, MYDNS_PTR **rptr, struct in_addr *addr)
 {
 	MYDNS_PTR *first = NULL, *last = NULL;
 	size_t	 querylen;
@@ -180,7 +180,7 @@ mydns_ptr_load(sql, rptr, addr)
 	if (rptr) *rptr = NULL;
 
 	/* Verify args */
-	if (!sql || !rptr)
+	if (!sqlConn || !rptr)
 	{
 		errno = EINVAL;
 		return (-1);
@@ -193,7 +193,7 @@ mydns_ptr_load(sql, rptr, addr)
 		mydns_ptr_table_name, addr->s_addr);
 
 	/* Submit query */
-	if (!(res = sql_query(sql, query, querylen)))
+	if (!(res = sql_query(sqlConn, query, querylen)))
 		return (-1);
 
 	/* Add results to list */
